@@ -1,14 +1,17 @@
 # -*- coding: utf-8 -*-
-'''Vendorized, partial version of scipy.constants which does not implement the full
-codata formulations.
-This was implemented to provide a consistent set of constants across scipy versions;
-and to prevent the tests from failing when new CODATA formulations come out.
-'''
+"""Vendorized, partial version of scipy.constants which does not implement the
+full codata formulations.
+
+This was implemented to provide a consistent set of constants across scipy
+versions; and to prevent the tests from failing when new CODATA formulations
+come out.
+"""
 
 import math as _math
 
 # mathematical constants
 pi = _math.pi
+pi_inv = 1.0/pi
 golden = golden_ratio = 1.618033988749895
 
 # SI prefixes
@@ -50,6 +53,7 @@ h = Planck = 6.62607004e-34
 hbar = h / (2.0 * pi)
 G = gravitational_constant = 6.67408e-11
 g = 9.80665
+g_sqrt = 3.1315571206669692#_math.sqrt(g)
 e = elementary_charge = 1.6021766208e-19
 alpha = fine_structure = 0.0072973525664
 N_A = Avogadro = 6.022140857e+23
@@ -60,7 +64,7 @@ Rydberg = 10973731.568508
 
 k = 1.380649e-23
 N_A = 6.02214076e23
-R = gas_constant = N_A*k #8.3144598 # N_A*k
+R = gas_constant = N_A*k # 8.31446261815324 exactly now, N_A*k
 R_inv = 1.0/R
 R2 = R*R
 
@@ -93,6 +97,7 @@ arcsec = arcsecond = arcmin / 60.0
 # time in second
 minute = 60.0
 hour = 60.0 * minute
+hour_inv = 1.0/hour
 day = 24.0 * hour
 week = 7.0 * day
 year = 365.0 * day
@@ -100,7 +105,10 @@ Julian_year = 365.25 * day
 
 # length in meter
 inch = 0.0254
+inch_inv = 1.0/inch
 foot = 12 * inch
+foot_cubed = foot*foot*foot
+foot_cubed_inv = 1.0/foot_cubed
 yard = 3 * foot
 mile = 1760 * yard
 mil = 0.001*inch 
@@ -119,6 +127,8 @@ parsec = au / arcsec
 atm = atmosphere = 101325.0
 bar = 1e5
 torr = mmHg = atm / 760
+inchHg = mmHg*inch*1000
+torr_inv = 1.0/torr
 psi = pound * g / (inch * inch)
 
 atm_inv = atmosphere_inv = 1.0/atm
@@ -167,3 +177,12 @@ dyn = dyne = 1e-5
 lbf = pound_force = pound * g
 kgf = kilogram_force = g # * 1 kg
 
+
+deg2rad = 0.017453292519943295769 # Multiple an angle in degrees by this to get radians
+rad2deg = 57.295779513082320877# Multiple an angle in radians by this to get degrees
+
+
+root_two = 1.4142135623730951
+
+ln_10 = _math.log(10)
+ln_10_inv = 1.0/ln_10
\ No newline at end of file
