@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
-'''Chemical Engineering Design Library (ChEDL). Utilities for process modeling.
-Copyright (C) 2016, Caleb Bell <Caleb.Andrew.Bell@gmail.com>
+"""Chemical Engineering Design Library (ChEDL). Utilities for process modeling.
+Copyright (C) 2016, 2017, 2018, 2019, 2020 Caleb Bell <Caleb.Andrew.Bell@gmail.com>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -18,23 +18,64 @@ FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-SOFTWARE.'''
+SOFTWARE.
+
+This module contains correlations for the drag coefficient `Cd` of a particle
+moving in a fluid. Numerical solvers for terminal velocity and an
+integrator for particle position over time are included also.
+
+For reporting bugs, adding feature requests, or submitting pull requests,
+please use the `GitHub issue tracker <https://github.com/CalebBell/fluids/>`_
+or contact the author at Caleb.Andrew.Bell@gmail.com.
+
+.. contents:: :local:
+
+Interfaces to Drag Models
+-------------------------
+.. autofunction:: drag_sphere
+.. autofunction:: v_terminal
+.. autofunction:: integrate_drag_sphere
+.. autofunction:: time_v_terminal_Stokes
+.. autofunction:: drag_sphere_methods
+
+Drag Correlations
+-----------------
+.. autofunction:: Stokes
+.. autofunction:: Barati
+.. autofunction:: Barati_high
+.. autofunction:: Khan_Richardson
+.. autofunction:: Morsi_Alexander
+.. autofunction:: Rouse
+.. autofunction:: Engelund_Hansen
+.. autofunction:: Clift_Gauvin
+.. autofunction:: Graf
+.. autofunction:: Flemmer_Banks
+.. autofunction:: Swamee_Ojha
+.. autofunction:: Yen
+.. autofunction:: Haider_Levenspiel
+.. autofunction:: Cheng
+.. autofunction:: Terfous
+.. autofunction:: Mikhailov_Freire
+.. autofunction:: Clift
+.. autofunction:: Ceylan
+.. autofunction:: Almedeij
+.. autofunction:: Morrison
+.. autofunction:: Song_Xu
+"""
 
 from __future__ import division
-from math import exp, log, log10, tanh
+from math import sqrt, exp, log, log10, tanh
 from fluids.constants import g
-from fluids.numerics import newton
+from fluids.numerics import secant
 from fluids.core import Reynolds
-from fluids.numerics import numpy as np
 
-__all__ = ['drag_sphere', 'v_terminal', 'integrate_drag_sphere',
+__all__ = ['drag_sphere', 'drag_sphere_methods', 'v_terminal', 'integrate_drag_sphere',
 'time_v_terminal_Stokes', 'Stokes',
 'Barati', 'Barati_high', 'Rouse', 'Engelund_Hansen',
 'Clift_Gauvin', 'Morsi_Alexander', 'Graf', 'Flemmer_Banks', 'Khan_Richardson',
 'Swamee_Ojha', 'Yen', 'Haider_Levenspiel', 'Cheng', 'Terfous',
 'Mikhailov_Freire', 'Clift', 'Ceylan', 'Almedeij', 'Morrison', 'Song_Xu']
 
-
 def Stokes(Re):
     r'''Calculates drag coefficient of a smooth sphere using Stoke's law.
 
@@ -107,9 +148,10 @@ def Barati(Re):
        Evolutionary Approach." Powder Technology 257 (May 2014): 11-19.
        doi:10.1016/j.powtec.2014.02.045.
     '''
-    Cd = (5.4856E9*tanh(4.3774E-9/Re) + 0.0709*tanh(700.6574/Re)
-    + 0.3894*tanh(74.1539/Re) - 0.1198*tanh(7429.0843/Re)
-    + 1.7174*tanh(9.9851/(Re+2.3384)) + 0.4744)
+    Re_inv = 1.0/Re
+    Cd = (5.4856E9*tanh(4.3774E-9*Re_inv) + 0.0709*tanh(700.6574*Re_inv)
+    + 0.3894*tanh(74.1539*Re_inv) - 0.1198*tanh(7429.0843*Re_inv)
+    + 1.7174*tanh(9.9851/(Re + 2.3384)) + 0.4744)
     return Cd
 
 
@@ -159,12 +201,15 @@ def Barati_high(Re):
     '''
     Re2 = Re*Re
     t0 = 1.0/Re
-    t1 = (Re/6530.)
-    t2 = (Re/1620.)
+    t1 = Re*(1.0/6530.)
+    t2 = Re*(1.0/1620)
     t3 = log10(Re2 + 10.7563)
+    t4 = 1.0/(Re+Re2)
+    t4 *= t4
+    t4 *= t4
     tanhRe = tanh(Re)
     Cd = (8E-6*(t1*t1 + tanhRe - 8.0*log10(Re))
-    - 0.4119*exp(-2.08E43/(Re+Re2)**4)
+    - 0.4119*exp(-2.08E43*t4)
     - 2.1344*exp(-t0*(t3*t3 + 9.9867))
     + 0.1357*exp(-t0*(t2*t2 + 10370.))
     - 8.5E-3*t0*(2.0*log10(tanh(tanhRe)) - 2825.7162) + 2.4795)
@@ -208,7 +253,7 @@ def Rouse(Re):
        Evolutionary Approach." Powder Technology 257 (May 2014): 11-19.
        doi:10.1016/j.powtec.2014.02.045.
     '''
-    return 24./Re + 3/Re**0.5 + 0.34
+    return 24./Re + 3/sqrt(Re) + 0.34
 
 
 def Engelund_Hansen(Re):
@@ -297,16 +342,45 @@ def Morsi_Alexander(Re):
     r'''Calculates drag coefficient of a smooth sphere using the method in
     [1]_ as described in [2]_.
 
+    If Re < 0.1:
+
     .. math::
-        C_D = \left\{ \begin{array}{ll}
-        \frac{24}{Re} & \mbox{if $Re < 0.1$}\\
-        \frac{22.73}{Re}+\frac{0.0903}{Re^2} + 3.69 & \mbox{if $0.1 < Re < 1$}\\
-        \frac{29.1667}{Re}-\frac{3.8889}{Re^2} + 1.2220 & \mbox{if $1 < Re < 10$}\\
-        \frac{46.5}{Re}-\frac{116.67}{Re^2} + 0.6167 & \mbox{if $10 < Re < 100$}\\
-        \frac{98.33}{Re}-\frac{2778}{Re^2} + 0.3644 & \mbox{if $100 < Re < 1000$}\\
-        \frac{148.62}{Re}-\frac{4.75\times10^4}{Re^2} + 0.3570 & \mbox{if $1000 < Re < 5000$}\\
-        \frac{-490.5460}{Re}+\frac{57.87\times10^4}{Re^2} + 0.46 & \mbox{if $5000 < Re < 10000$}\\
-        \frac{-1662.5}{Re}+\frac{5.4167\times10^6}{Re^2} + 0.5191 & \mbox{if $10000 < Re < 50000$}\end{array} \right.
+        C_D = \frac{24}{Re}
+
+    If 0.1 < Re < 1:
+
+    .. math::
+        C_D = \frac{22.73}{Re}+\frac{0.0903}{Re^2} + 3.69
+
+    If 1 < Re < 10:
+
+    .. math::
+        C_D = \frac{29.1667}{Re}-\frac{3.8889}{Re^2} + 1.2220
+
+    If 10 < Re < 100:
+
+    .. math::
+        C_D =\frac{46.5}{Re}-\frac{116.67}{Re^2} + 0.6167
+
+    If 100 < Re < 1000:
+
+    .. math::
+        C_D = \frac{98.33}{Re}-\frac{2778}{Re^2} + 0.3644
+
+    If 1000 < Re < 5000:
+
+    .. math::
+        C_D =  \frac{148.62}{Re}-\frac{4.75\times10^4}{Re^2} + 0.3570
+
+    If 5000 < Re < 10000:
+
+    .. math::
+        C_D = \frac{-490.5460}{Re}+\frac{57.87\times10^4}{Re^2} + 0.46
+
+    If 10000 < Re < 50000:
+
+    .. math::
+        C_D = \frac{-1662.5}{Re}+\frac{5.4167\times10^6}{Re^2} + 0.5191
 
     Parameters
     ----------
@@ -395,7 +469,7 @@ def Graf(Re):
        Evolutionary Approach." Powder Technology 257 (May 2014): 11-19.
        doi:10.1016/j.powtec.2014.02.045.
     '''
-    return 24./Re + 7.3/(1 + Re**0.5) + 0.25
+    return 24./Re + 7.3/(1 + sqrt(Re)) + 0.25
 
 
 def Flemmer_Banks(Re):
@@ -523,7 +597,7 @@ def Swamee_Ojha(Re):
        Evolutionary Approach." Powder Technology 257 (May 2014): 11-19.
        doi:10.1016/j.powtec.2014.02.045.
     '''
-    Cd = 0.5*(16*((24./Re)**1.6 + (130./Re)**0.72)**2.5 + ((40000./Re)**2 + 1)**-0.25)**0.25
+    Cd = 0.5*sqrt(sqrt(16*((24./Re)**1.6 + (130./Re)**0.72)**2.5 + 1.0/sqrt(sqrt((40000./Re)**2 + 1))))
     return Cd
 
 
@@ -565,7 +639,7 @@ def Yen(Re):
        Evolutionary Approach." Powder Technology 257 (May 2014): 11-19.
        doi:10.1016/j.powtec.2014.02.045.
     '''
-    return 24./Re*(1 + 0.15*Re**0.5 + 0.017*Re) - 0.208/(1 + 1E4*Re**-0.5)
+    return 24./Re*(1 + 0.15*sqrt(Re) + 0.017*Re) - 0.208/(1 + 1E4*1.0/sqrt(Re))
 
 
 def Haider_Levenspiel(Re):
@@ -742,17 +816,50 @@ def Clift(Re):
     r'''Calculates drag coefficient of a smooth sphere using the method in
     [1]_ as described in [2]_.
 
+    If Re < 0.01:
+
     .. math::
-        C_D = \left\{ \begin{array}{ll}
-        \frac{24}{Re} + \frac{3}{16} & \mbox{if $Re < 0.01$}\\
-        \frac{24}{Re}(1 + 0.1315Re^{0.82 - 0.05\log Re}) & \mbox{if $0.01 < Re < 20$}\\
-        \frac{24}{Re}(1 + 0.1935Re^{0.6305}) & \mbox{if $20 < Re < 260$}\\
-        10^{[1.6435 - 1.1242\log Re + 0.1558[\log Re]^2} & \mbox{if $260 < Re < 1500$}\\
-        10^{[-2.4571 + 2.5558\log Re - 0.9295[\log Re]^2 + 0.1049[\log Re]^3} & \mbox{if $1500 < Re < 12000$}\\
-        10^{[-1.9181 + 0.6370\log Re - 0.0636[\log Re]^2} & \mbox{if $12000 < Re < 44000$}\\
-        10^{[-4.3390 + 1.5809\log Re - 0.1546[\log Re]^2} & \mbox{if $44000 < Re < 338000$}\\
-        9.78 - 5.3\log Re & \mbox{if $338000 < Re < 400000$}\\
-        0.19\log Re - 0.49 & \mbox{if $400000 < Re < 1000000$}\end{array} \right.
+        C_D = \frac{24}{Re} + \frac{3}{16}
+
+    If 0.01 < Re < 20:
+
+    .. math::
+        C_D = \frac{24}{Re}(1 + 0.1315Re^{0.82 - 0.05\log_{10} Re})
+
+    If 20 < Re < 260:
+
+    .. math::
+        C_D = \frac{24}{Re}(1 + 0.1935Re^{0.6305})
+
+    If 260 < Re < 1500:
+
+    .. math::
+        C_D = 10^{[1.6435 - 1.1242\log_{10} Re + 0.1558[\log_{10} Re]^2}
+
+    If 1500 < Re < 12000:
+
+    .. math::
+        C_D = 10^{[-2.4571 + 2.5558\log_{10} Re - 0.9295[\log_{10} Re]^2 + 0.1049[\log_{10} Re]^3}
+
+    If 12000 < Re < 44000:
+
+    .. math::
+        C_D = 10^{[-1.9181 + 0.6370\log_{10} Re - 0.0636[\log_{10} Re]^2}
+
+    If 44000 < Re < 338000:
+
+    .. math::
+        C_D = 10^{[-4.3390 + 1.5809\log_{10} Re - 0.1546[\log_{10} Re]^2}
+
+    If 338000 < Re < 400000:
+
+    .. math::
+        C_D = 9.78 - 5.3\log_{10} Re
+
+    If 400000 < Re < 1000000:
+
+    .. math::
+        C_D = 0.19\log_{10} Re - 0.49
 
     Parameters
     ----------
@@ -847,8 +954,8 @@ def Ceylan(Re):
        Evolutionary Approach." Powder Technology 257 (May 2014): 11-19.
        doi:10.1016/j.powtec.2014.02.045.
     '''
-    Cd = (1 - 0.5*exp(0.182) + 10.11*Re**(-2/3.)*exp(0.952*Re**-0.25)
-    - 0.03859*Re**(-4/3.)*exp(1.30*Re**-0.5) + 0.037E-4*Re*exp(-0.125E-4*Re)
+    Cd = (1 - 0.5*exp(0.182) + 10.11*Re**(-2/3.)*exp(0.952/sqrt(sqrt(Re)))
+    - 0.03859*Re**(-4/3.)*exp(1.30/sqrt(Re)) + 0.037E-4*Re*exp(-0.125E-4*Re)
     - 0.116E-10*Re**2*exp(-0.444E-5*Re))
     return Cd
 
@@ -962,7 +1069,7 @@ def Song_Xu(Re, sphericity=1., S=1.):
 
     .. math::
         C_d = \frac{24}{Re\phi^{0.65}S^{0.3}}\left(1 + 0.35Re\right)^{0.44}
-        
+
     Parameters
     ----------
     Re : float
@@ -981,7 +1088,7 @@ def Song_Xu(Re, sphericity=1., S=1.):
 
     Notes
     -----
-    Notable as its experimental data and analysis is included in their 
+    Notable as its experimental data and analysis is included in their
     supporting material.
 
     Examples
@@ -991,10 +1098,10 @@ def Song_Xu(Re, sphericity=1., S=1.):
 
     References
     ----------
-    .. [1] Song, Xianzhi, Zhengming Xu, Gensheng Li, Zhaoyu Pang, and Zhaopeng 
-       Zhu. "A New Model for Predicting Drag Coefficient and Settling Velocity 
-       of Spherical and Non-Spherical Particle in Newtonian Fluid." Powder 
-       Technology 321 (November 2017): 242-50. 
+    .. [1] Song, Xianzhi, Zhengming Xu, Gensheng Li, Zhaoyu Pang, and Zhaopeng
+       Zhu. "A New Model for Predicting Drag Coefficient and Settling Velocity
+       of Spherical and Non-Spherical Particle in Newtonian Fluid." Powder
+       Technology 321 (November 2017): 242-50.
        doi:10.1016/j.powtec.2017.08.017.
     '''
     return 24/(Re*sphericity**0.65*S**0.3)*(1+0.35*Re)**0.44
@@ -1024,15 +1131,46 @@ drag_sphere_correlations = {
     'Song_Xu': (Song_Xu, None, 1E3)
 }
 
+def drag_sphere_methods(Re, check_ranges=True):
+    r'''This function returns a list of methods that can be used to calculate
+    the drag coefficient of a sphere.
+    Twenty one methods are available, all requiring only the Reynolds number of
+    the sphere. Most methods are valid from Re=0 to Re=200,000.
 
-def drag_sphere(Re, Method=None, AvailableMethods=False):
+    Examples
+    --------
+    >>> len(drag_sphere_methods(200))
+    20
+    >>> len(drag_sphere_methods(200000, check_ranges=False))
+    21
+    >>> len(drag_sphere_methods(200000, check_ranges=True))
+    5
+
+    Parameters
+    ----------
+    Re : float
+        Particle Reynolds number of the sphere using the surrounding fluid
+        density and viscosity, [-]
+    check_ranges : bool, optional
+        Whether to return only correlations claiming to be valid for the given
+        `Re` or not, [-]
+
+    Returns
+    -------
+    methods : list, only returned if AvailableMethods == True
+        List of methods which can be used to calculate `Cd` with the given `Re`
+    '''
+    methods = []
+    for key, (func, Re_min, Re_max) in drag_sphere_correlations.items():
+        if ((Re_min is None or Re > Re_min) and (Re_max is None or Re < Re_max)) or not check_ranges:
+            methods.append(key)
+    return methods
+
+def drag_sphere(Re, Method=None):
     r'''This function handles calculation of drag coefficient on spheres.
     Twenty methods are available, all requiring only the Reynolds number of the
     sphere. Most methods are valid from Re=0 to Re=200,000. A correlation will
-    be automatically selected if none is specified. The full list of correlations
-    valid for a given Reynolds number can be obtained with the `AvailableMethods`
-    flag.
-
+    be automatically selected if none is specified.
     If no correlation is selected, the following rules are used:
 
         * If Re < 0.01, use Stoke's solution.
@@ -1058,27 +1196,14 @@ def drag_sphere(Re, Method=None, AvailableMethods=False):
     -------
     Cd : float
         Drag coefficient [-]
-    methods : list, only returned if AvailableMethods == True
-        List of methods which can be used to calculate `Cd` with the given `Re`
 
     Other Parameters
     ----------------
     Method : string, optional
         A string of the function name to use, as in the dictionary
         drag_sphere_correlations
-    AvailableMethods : bool, optional
-        If True, function will consider which methods which can be used to
-        calculate `Cd` with the given `Re`
     '''
-    def list_methods():
-        methods = []
-        for key, (func, Re_min, Re_max) in drag_sphere_correlations.items():
-            if (Re_min is None or Re > Re_min) and (Re_max is None or Re < Re_max):
-                methods.append(key)
-        return methods
-    if AvailableMethods:
-        return list_methods()
-    if not Method:
+    if Method is None:
         if Re > 0.1:
             # Smooth transition point between the two models
             if Re <= 212963.26847812787:
@@ -1095,12 +1220,56 @@ def drag_sphere(Re, Method=None, AvailableMethods=False):
         else:
             return Stokes(Re)
 
-    if Method in drag_sphere_correlations:
-        return drag_sphere_correlations[Method][0](Re)
+    if Method == "Stokes":
+        return Stokes(Re)
+    elif Method == "Barati":
+        return Barati(Re)
+    elif Method == "Barati_high":
+        return Barati_high(Re)
+    elif Method == "Rouse":
+        return Rouse(Re)
+    elif Method == "Engelund_Hansen":
+        return Engelund_Hansen(Re)
+    elif Method == "Clift_Gauvin":
+        return Clift_Gauvin(Re)
+    elif Method == "Morsi_Alexander":
+        return Morsi_Alexander(Re)
+    elif Method == "Graf":
+        return Graf(Re)
+    elif Method == "Flemmer_Banks":
+        return Flemmer_Banks(Re)
+    elif Method == "Khan_Richardson":
+        return Khan_Richardson(Re)
+    elif Method == "Swamee_Ojha":
+        return Swamee_Ojha(Re)
+    elif Method == "Yen":
+        return Yen(Re)
+    elif Method == "Haider_Levenspiel":
+        return Haider_Levenspiel(Re)
+    elif Method == "Cheng":
+        return Cheng(Re)
+    elif Method == "Terfous":
+        return Terfous(Re)
+    elif Method == "Mikhailov_Freire":
+        return Mikhailov_Freire(Re)
+    elif Method == "Clift":
+        return Clift(Re)
+    elif Method == "Ceylan":
+        return Ceylan(Re)
+    elif Method == "Almedeij":
+        return Almedeij(Re)
+    elif Method == "Morrison":
+        return Morrison(Re)
+    elif Method == "Song_Xu":
+        return Song_Xu(Re)
     else:
-        raise Exception('Failure in in function')
+        raise ValueError('Unrecognized method')
 
 
+def _v_terminal_err(V, Method, Re_almost, main):
+    Cd = drag_sphere(Re_almost*V, Method=Method)
+    return V - sqrt(main/Cd)
+
 def v_terminal(D, rhop, rho, mu, Method=None):
     r'''Calculates terminal velocity of a falling sphere using any drag
     coefficient method supported by `drag_sphere`. The laminar solution for
@@ -1145,11 +1314,11 @@ def v_terminal(D, rhop, rho, mu, Method=None):
     0.004142497244531304
 
     Example 7-1 in GPSA handbook, 13th edition:
-        
+
     >>> from scipy.constants import *
     >>> v_terminal(D=150E-6, rhop=31.2*lb/foot**3, rho=2.07*lb/foot**3,  mu=1.2e-05)/foot
     0.4491992020345101
-    
+
     The answer reported there is 0.46 ft/sec.
 
     References
@@ -1177,26 +1346,23 @@ def v_terminal(D, rhop, rho, mu, Method=None):
     main = 4/3.*g*D*(rhop-rho)/rho
     V_max = 1E6/rho/D*mu  # where the correlation breaks down, Re=1E6
 
-    def err(V):
-        Cd = drag_sphere(Re_almost*V, Method=Method)
-        return V - (main/Cd)**0.5
     # Begin the solver with 1/100 th the velocity possible at the maximum
     # Reynolds number the correlation is good for
-    return float(newton(err, V_max/100, tol=1E-12))
+    return secant(_v_terminal_err, V_max*1e-2, xtol=1E-12, args=(Method, Re_almost, main))
 
 
 def time_v_terminal_Stokes(D, rhop, rho, mu, V0, tol=1e-14):
     r'''Calculates the time required for a particle in Stoke's regime only to
     reach terminal velocity (approximately). An infinitely long period is
-    required theoretically, but with floating points, it is possible to 
-    calculate the time required to come within a specified `tol` of that 
+    required theoretically, but with floating points, it is possible to
+    calculate the time required to come within a specified `tol` of that
     terminal velocity.
-    
+
     .. math::
-        t_{term} = -\frac{1}{18\mu}\ln \left(\frac{D^2g\rho - D^2 g \rho_p 
-        + 18\mu V_{term}}{D^2g\rho - D^2 g \rho_p + 18\mu V_0 } \right) D^2 
+        t_{term} = -\frac{1}{18\mu}\ln \left(\frac{D^2g\rho - D^2 g \rho_p
+        + 18\mu V_{term}}{D^2g\rho - D^2 g \rho_p + 18\mu V_0 } \right) D^2
         \rho_p
-    
+
     Parameters
     ----------
     D : float
@@ -1223,7 +1389,7 @@ def time_v_terminal_Stokes(D, rhop, rho, mu, V0, tol=1e-14):
     Notes
     -----
     The symbolic solution was obtained via Wolfram Alpha.
-    
+
     If a solution cannot be obtained due to floating point error at very high
     tolerance, an exception is raised - but first, the tolerance is doubled,
     up to fifty times in an attempt to obtain the highest possible precision
@@ -1232,15 +1398,15 @@ def time_v_terminal_Stokes(D, rhop, rho, mu, V0, tol=1e-14):
 
     Examples
     --------
-    >>> time_v_terminal_Stokes(D=1e-7, rhop=2200., rho=1.2, mu=1.78E-5, V0=1) 
-    3.188003113787153e-06
-    >>> time_v_terminal_Stokes(D=1e-2, rhop=2200., rho=1.2, mu=1.78E-5, V0=1, 
+    >>> time_v_terminal_Stokes(D=1e-7, rhop=2200., rho=1.2, mu=1.78E-5, V0=1)
+    3.1880031137871528e-06
+    >>> time_v_terminal_Stokes(D=1e-2, rhop=2200., rho=1.2, mu=1.78E-5, V0=1,
     ... tol=1e-30)
-    24800.636391802
+    24800.636391801996
     '''
     if tol < 1e-17:
         tol = 2e-17
-    term = D*D*g*rho - D*D*g*rhop 
+    term = D*D*g*rho - D*D*g*rhop
     denominator = term + 18.*mu*V0
     v_term_base = g*D*D*(rhop-rho)/(18.*mu)
 
@@ -1253,11 +1419,11 @@ def time_v_terminal_Stokes(D, rhop, rho, mu, V0, tol=1e-14):
                 v_term = v_term_base*(1.0 - tol)
             numerator = term + 18.*mu*v_term
             return log(numerator/denominator)*const
-        except ValueError:
+        except:
             tol = tol + tol
             if tol > 0.01:
-                raise Exception('Could not find a solution')
-    raise Exception('Could not find a solution')
+                raise ValueError('Could not find a solution')
+    raise ValueError('Could not find a solution')
 
 
 def integrate_drag_sphere(D, rhop, rho, mu, t, V=0, Method=None,
@@ -1301,42 +1467,45 @@ def integrate_drag_sphere(D, rhop, rho, mu, t, V=0, Method=None,
     Notes
     -----
     This can be relatively slow as drag correlations can be complex.
-    
-    There are analytical solutions available for the Stokes law regime (Re < 
+
+    There are analytical solutions available for the Stokes law regime (Re <
     0.3). They were obtained from Wolfram Alpha. [1]_ was not used in the
     derivation, but also describes the derivation fully.
-    
+
     .. math::
         V(t) = \frac{\exp(-at) (V_0 a + b(\exp(at) - 1))}{a}
-        
+
     .. math::
-        x(t) = \frac{\exp(-a t)\left[V_0 a(\exp(a t) - 1) + b\exp(a t)(a t-1) 
+        x(t) = \frac{\exp(-a t)\left[V_0 a(\exp(a t) - 1) + b\exp(a t)(a t-1)
         + b\right]}{a^2}
-    
+
     .. math::
         a = \frac{18\mu_f}{D^2\rho_p}
-    
+
     .. math::
         b = \frac{g(\rho_p-\rho_f)}{\rho_p}
-        
-    The analytical solution will automatically be used if the initial and 
+
+    The analytical solution will automatically be used if the initial and
     terminal velocity is show the particle's behavior to be laminar. Note
     that this behavior requires that the terminal velocity of the particle be
-    solved for - this adds slight (1%) overhead for the cases where particles 
+    solved for - this adds slight (1%) overhead for the cases where particles
     are not laminar.
 
     Examples
     --------
     >>> integrate_drag_sphere(D=0.001, rhop=2200., rho=1.2, mu=1.78E-5, t=0.5,
-    ... V=30, distance=True) 
-    (9.686465044053476, 7.8294546436299175)
-    
+    ... V=30, distance=True)
+    (9.68646, 7.82945)
+
     References
     ----------
-    .. [1] Timmerman, Peter, and Jacobus P. van der Weele. "On the Rise and 
-       Fall of a Ball with Linear or Quadratic Drag." American Journal of 
+    .. [1] Timmerman, Peter, and Jacobus P. van der Weele. "On the Rise and
+       Fall of a Ball with Linear or Quadratic Drag." American Journal of
        Physics 67, no. 6 (June 1999): 538-46. https://doi.org/10.1119/1.19320.
     '''
+    # Delayed import of necessaray functions
+    from scipy.integrate import odeint, cumtrapz
+    import numpy as np
     laminar_initial = Reynolds(V=V, rho=rho, D=D, mu=mu) < 0.01
     v_laminar_end_assumed = v_terminal(D=D, rhop=rhop, rho=rho, mu=mu, Method=Method)
     laminar_end = Reynolds(V=v_laminar_end_assumed, rho=rho, D=D, mu=mu) < 0.01
@@ -1354,7 +1523,7 @@ def integrate_drag_sphere(D, rhop, rho, mu, t, V=0, Method=None,
             # It is only necessary to integrate to terminal velocity
             t_to_terminal = time_v_terminal_Stokes(D, rhop, rho, mu, V0=V, tol=1e-9)
             if t_to_terminal > t:
-                raise Exception('Should never happen')
+                raise ValueError('Should never happen')
             V_end, x_end = integrate_drag_sphere(D=D, rhop=rhop, rho=rho, mu=mu, t=t_to_terminal, V=V, Method='Stokes', distance=True)
             # terminal velocity has been reached - V does not change, but x does
             # No reason to believe this isn't working even though it isn't
@@ -1363,7 +1532,7 @@ def integrate_drag_sphere(D, rhop, rho, mu, t, V=0, Method=None,
                 return V_end, x_end + V_end*(t - t_to_terminal)
             else:
                 return V_end
-            
+
             # This is a serious problem for small diameters
             # It would be possible to step slowly, using smaller increments
             # of time to avlid overflows. However, this unfortunately quickly
@@ -1382,7 +1551,7 @@ def integrate_drag_sphere(D, rhop, rho, mu, t, V=0, Method=None,
 #                return V, x
 #            else:
 #                return V
-    
+
     Re_ish = rho*D/mu
     c1 = g*(rhop-rho)/rhop
     c2 = -0.75*rho/(D*rhop)
@@ -1393,7 +1562,7 @@ def integrate_drag_sphere(D, rhop, rho, mu, t, V=0, Method=None,
             t2 = 0.0
         else:
 #            t2 = c2*V*V*Stokes(Re_ish*V)
-            t2 = c2*V*V*drag_sphere(Re_ish*V, Method=Method)
+            t2 = c2*V*V*drag_sphere(float(Re_ish*V), Method=Method)
         return c1 + t2
 
     # Number of intervals for the solution to be solved for; the integrator
@@ -1401,9 +1570,7 @@ def integrate_drag_sphere(D, rhop, rho, mu, t, V=0, Method=None,
     # For an accurate integration of the particle's distance traveled
     pts = 1000 if distance else 2
     ts = np.linspace(0, t, pts)
-    
-    # Delayed import of necessaray functions
-    from scipy.integrate import odeint, cumtrapz
+
 
     # Perform the integration
     Vs = odeint(dv_dt, [V], ts)
