@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
-'''Chemical Engineering Design Library (ChEDL). Utilities for process modeling.
+# type: ignore
+"""Chemical Engineering Design Library (ChEDL). Utilities for process modeling.
 Copyright (C) 2019 Caleb Bell <Caleb.Andrew.Bell@gmail.com>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -18,48 +19,58 @@ FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-SOFTWARE.'''
+SOFTWARE.
+"""
 
 from __future__ import division
-from math import sin, exp, pi, fabs, copysign, log, isinf, acos, cos, sin
+from math import sin, exp, pi, fabs, copysign, log, isinf, acos, cos, sin, sqrt
 import sys
-from sys import float_info
-try:
-    import numpy as np
-except ImportError:
-    np = None
-try:
-    # The right way imports the platform module which costs to ms to load!
-    # implementation = platform.python_implementation()
-    IS_PYPY = 'PyPy' in sys.version
-except AttributeError:
-    IS_PYPY = False
+
+REQUIRE_DEPENDENCIES = False
+if not REQUIRE_DEPENDENCIES:
+    IS_PYPY = True
+else:
+    try:
+        # The right way imports the platform module which costs to ms to load!
+        # implementation = platform.python_implementation()
+        IS_PYPY = 'PyPy' in sys.version
+    except AttributeError:
+        IS_PYPY = False
+
+#IS_PYPY = True # for testing
+    
+#if not IS_PYPY and not REQUIRE_DEPENDENCIES:
+#    try:
+#        import numpy as np
+#    except ImportError:
+#        np = None
 
 __all__ = ['dot', 'inv', 'det', 'solve', 'norm2', 'inner_product',
            'eye', 'array_as_tridiagonals', 'solve_tridiagonal', 'subset_matrix']
+primitive_containers = frozenset([list, tuple])
 
 def det(matrix):
-    '''Seem sto work fine.
-    
+    """Seem sto work fine.
+
     >> from sympy import *
     >> from sympy.abc import *
     >> Matrix([[a, b], [c, d]]).det()
     a*d - b*c
     >> Matrix([[a, b, c], [d, e, f], [g, h, i]]).det()
     a*e*i - a*f*h - b*d*i + b*f*g + c*d*h - c*e*g
-    
+
     A few terms can be slightly factored out of the 3x dim.
-    
+
     >> Matrix([[a, b, c, d], [e, f, g, h], [i, j, k, l], [m, n, o, p]]).det()
     a*f*k*p - a*f*l*o - a*g*j*p + a*g*l*n + a*h*j*o - a*h*k*n - b*e*k*p + b*e*l*o + b*g*i*p - b*g*l*m - b*h*i*o + b*h*k*m + c*e*j*p - c*e*l*n - c*f*i*p + c*f*l*m + c*h*i*n - c*h*j*m - d*e*j*o + d*e*k*n + d*f*i*o - d*f*k*m - d*g*i*n + d*g*j*m
 
     72 mult vs ~48 in cse'd version'
-    
+
     Commented out - takes a few seconds
     >> #Matrix([[a, b, c, d, e], [f, g, h, i, j], [k, l, m, n, o], [p, q, r, s, t], [u, v, w, x, y]]).det()
-    
+
     260 multiplies with cse; 480 without it.
-    '''
+    """
     size = len(matrix)
     if size == 1:
         return matrix[0]
@@ -184,26 +195,26 @@ def det(matrix):
 
 
 def inv(matrix):
-    '''
-    5 has way too many multiplies.
+    """5 has way too many multiplies.
+
     >> from sympy import *
     >> from sympy.abc import *
     >> Matrix([a]).inv()
     Matrix([[1/a]])
-    
+
     >> cse(Matrix([[a, b], [c, d]]).inv())
     Matrix([
     [1/a + b*c/(a**2*(d - b*c/a)), -b/(a*(d - b*c/a))],
     [          -c/(a*(d - b*c/a)),      1/(d - b*c/a)]])
-    
+
     >> m_3 = Matrix([[a, b, c], [d, e, f], [g, h, i]])
     >> #cse(m_3.inv())
 
     >> m_4 = Matrix([[a, b, c, d], [e, f, g, h], [i, j, k, l], [m, n, o, p]])
     >> cse(m_4.inv())
-    
+
     # Note: for 3, 4 - forgot to generate code using optimizations='basic'
-    '''
+    """
     size = len(matrix)
     if size == 1:
         try:
@@ -220,6 +231,7 @@ def inv(matrix):
             return [[x0 + b*x3*x0*x0, -x1*x2],
                     [-x0*x3, x2]]
         except:
+            import numpy as np
             return np.linalg.inv(matrix).tolist()
     elif size == 3:
         (a, b, c), (d, e, f), (g, h, i) = matrix
@@ -327,6 +339,67 @@ def inv(matrix):
 #        import numpy as np
 #        return np.linalg.inv(matrix).tolist()
 
+
+def shape(value):
+    '''Find and return the shape of an array, whether it is a numpy array or 
+    a list-of-lists or other combination of iterators.
+    
+    Parameters
+    ----------
+    value : various
+        Input array, [-]
+
+    Returns
+    -------
+    shape : tuple(int, dimension)
+        Dimensions of array, [-]
+    
+    Notes
+    -----
+    It is assumed the shape is consistent - not something like [[1.1, 2.2], [2.4]]
+
+    Examples
+    --------
+    >>> shape([])
+    (0,)
+    >>> shape([1.1, 2.2, 5.5])
+    (3,)
+    >>> shape([[1.1, 2.2, 5.5], [2.0, 1.1, 1.5]])
+    (2, 3)
+    >>> shape([[[1.1,], [2.0], [1.1]]])
+    (1, 3, 1)
+    >>> shape(['110-54-3'])
+    (1,)
+    '''
+    try:
+        return value.shape
+    except:
+        pass
+    dims = [len(value)]
+    try:
+        # Except this block to handle the case of no value
+        iter_value = value[0]
+        for i in range(10):
+            # try:
+            if type(iter_value) in primitive_containers:
+                dims.append(len(iter_value))
+                iter_value = iter_value[0]
+            else:
+                break
+            # except:
+            #     break
+    except:
+        pass
+    return tuple(dims)
+    # try:
+    #     try:
+    #         new_shape = (len(value), len(value[0]), len(value[0][0]))
+    #     except:
+    #         new_shape = (len(value), len(value[0]))
+    # except:
+    #     new_shape = (len(value),)
+    # return new_shape
+
 def eye(N):
     mat = []
     for i in range(N):
@@ -447,6 +520,7 @@ def solve(a, b):
     if len(a) > 4:
         if IS_PYPY or np is None:
             return solve_LU_decomposition(a, b)
+        import numpy as np
         return np.linalg.solve(a, b).tolist()
     else:
         return dot(inv(a), b)
@@ -457,7 +531,7 @@ def norm2(arr):
     tot = 0.0
     for i in arr:
         tot += i*i
-    return tot**0.5
+    return sqrt(tot)
 
 
 def array_as_tridiagonals(arr):
