@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
-'''Chemical Engineering Design Library (ChEDL). Utilities for process modeling.
-Copyright (C) 2016, Caleb Bell <Caleb.Andrew.Bell@gmail.com>
+"""Chemical Engineering Design Library (ChEDL). Utilities for process modeling.
+Copyright (C) 2016, 2017, 2018, 2020 Caleb Bell <Caleb.Andrew.Bell@gmail.com>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -18,10 +18,46 @@ FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-SOFTWARE.'''
+SOFTWARE.
+
+This module contains functionality for calculating the flow rate of fluids
+in open channels. The Manning and Chezy methods are implemented Weirs as well
+as several calculations for flow rate over weirs.
+
+For reporting bugs, adding feature requests, or submitting pull requests,
+please use the `GitHub issue tracker <https://github.com/CalebBell/fluids/>`_
+or contact the author at Caleb.Andrew.Bell@gmail.com.
+
+.. contents:: :local:
+
+Weirs
+-----
+.. autofunction:: Q_weir_V_Shen
+.. autofunction:: Q_weir_rectangular_Kindsvater_Carter
+.. autofunction:: Q_weir_rectangular_SIA
+.. autofunction:: Q_weir_rectangular_full_Ackers
+.. autofunction:: Q_weir_rectangular_full_SIA
+.. autofunction:: Q_weir_rectangular_full_Rehbock
+.. autofunction:: Q_weir_rectangular_full_Kindsvater_Carter
+
+Manning and Chezy Equations
+---------------------------
+.. autofunction:: V_Manning
+.. autofunction:: V_Chezy
+.. autofunction:: n_Manning_to_C_Chezy
+.. autofunction:: C_Chezy_to_n_Manning
+
+Manning Coefficients
+--------------------
+.. autodata:: n_natural
+.. autodata:: n_excavated_dredged
+.. autodata:: n_lined_built
+.. autodata:: n_closed_conduit
+.. autodata:: n_dicts
+"""
 
 from __future__ import division
-from math import tan, radians
+from math import tan, radians, sqrt
 from fluids.constants import g
 from fluids.numerics import interp
 
@@ -91,7 +127,7 @@ def Q_weir_V_Shen(h1, angle=90):
     Examples
     --------
     >>> Q_weir_V_Shen(0.6, angle=45)
-    0.21071725775478228
+    0.21071725775478
 
     References
     ----------
@@ -103,8 +139,8 @@ def Q_weir_V_Shen(h1, angle=90):
        Van Nostrand Reinhold Co., 1984.
     '''
     C = interp(angle, angles_Shen, Cs_Shen)
-    k = interp(angle, angles_Shen, k_Shen)    
-    return C*tan(radians(angle)/2)*g**0.5*(h1 + k)**2.5
+    k = interp(angle, angles_Shen, k_Shen)
+    return C*tan(radians(angle)/2)*sqrt(g)*(h1 + k)**2.5
 
 
 ### Rectangular Weirs
@@ -159,7 +195,7 @@ def Q_weir_rectangular_Kindsvater_Carter(h1, h2, b):
     .. [2] Blevins, Robert D. Applied Fluid Dynamics Handbook. New York, N.Y.:
        Van Nostrand Reinhold Co., 1984.
     '''
-    return 0.554*(1 - 0.0035*h1/h2)*(b + 0.0025)*g**0.5*(h1 + 0.0001)**1.5
+    return 0.554*(1 - 0.0035*h1/h2)*(b + 0.0025)*sqrt(g)*(h1 + 0.0001)**1.5
 
 
 def Q_weir_rectangular_SIA(h1, h2, b, b1):
@@ -216,7 +252,7 @@ def Q_weir_rectangular_SIA(h1, h2, b, b1):
     '''
     h = h1 + h2
     Q = 0.544*(1 + 0.064*(b/b1)**2 + (0.00626 - 0.00519*(b/b1)**2)/(h1 + 0.0016))\
-    *(1 + 0.5*(b/b1)**4*(h1/(h1 + h2))**2)*b*g**0.5*h**1.5
+    *(1 + 0.5*(b/b1)**4*(h1/(h1 + h2))**2)*b*sqrt(g)*h**1.5
     return Q
 
 
@@ -272,7 +308,7 @@ def Q_weir_rectangular_full_Ackers(h1, h2, b):
     .. [3] Cengel, Yunus, and John Cimbala. Fluid Mechanics: Fundamentals and
        Applications. Boston: McGraw Hill Higher Education, 2006.
     '''
-    return 0.564*(1 + 0.150*h1/h2)*b*g**0.5*(h1 + 0.001)**1.5
+    return 0.564*(1 + 0.150*h1/h2)*b*sqrt(g)*(h1 + 0.001)**1.5
 
 
 def Q_weir_rectangular_full_SIA(h1, h2, b):
@@ -325,8 +361,8 @@ def Q_weir_rectangular_full_SIA(h1, h2, b):
     .. [2] Blevins, Robert D. Applied Fluid Dynamics Handbook. New York, N.Y.:
        Van Nostrand Reinhold Co., 1984.
     '''
-    Q = 2/3.*2**0.5*(0.615 + 0.000615/(h1 + 0.0016))*b*g**0.5*h1 \
-    + 0.5*(h1/(h1+h2))**2*b*g**0.5*h1**1.5
+    Q = 2/3.*sqrt(2)*(0.615 + 0.000615/(h1 + 0.0016))*b*sqrt(g)*h1 \
+    + 0.5*(h1/(h1+h2))**2*b*sqrt(g)*h1**1.5
     return Q
 
 
@@ -380,7 +416,7 @@ def Q_weir_rectangular_full_Rehbock(h1, h2, b):
     .. [2] Blevins, Robert D. Applied Fluid Dynamics Handbook. New York, N.Y.:
        Van Nostrand Reinhold Co., 1984.
     '''
-    return 2/3.*2**0.5*(0.602 + 0.0832*h1/h2)*b*g**0.5*(h1+0.00125)**1.5
+    return 2/3.*sqrt(2)*(0.602 + 0.0832*h1/h2)*b*sqrt(g)*(h1+0.00125)**1.5
 
 #print [Q_weir_rectangular_full_Rehbock(h1=0.3, h2=0.4, b=2)]
 
@@ -433,7 +469,7 @@ def Q_weir_rectangular_full_Kindsvater_Carter(h1, h2, b):
     .. [2] Blevins, Robert D. Applied Fluid Dynamics Handbook. New York, N.Y.:
        Van Nostrand Reinhold Co., 1984.
     '''
-    Q = 2/3.*2**0.5*(0.602 + 0.075*h1/h2)*(b - 0.001)*g**0.5*(h1 + 0.001)**1.5
+    Q = 2/3.*sqrt(2)*(0.602 + 0.075*h1/h2)*(b - 0.001)*sqrt(g)*(h1 + 0.001)**1.5
     return Q
 #print [Q_weir_rectangular_full_Kindsvater_Carter(h1=0.3, h2=0.4, b=2)]
 
@@ -458,7 +494,8 @@ def V_Manning(Rh, S, n):
     S : float
         Slope of the channel, m/m [-]
     n : float
-        Manning roughness coefficient [s/m^(1/3)]
+        Manning roughness coefficient; traditionally in the correct units,
+        [s/m^(1/3)]
 
     Returns
     -------
@@ -468,6 +505,8 @@ def V_Manning(Rh, S, n):
     Notes
     -----
     This is equation is often given in imperial units multiplied by 1.49.
+    Although `n` could be converted to be in imperial units, in practice this
+    has not been done and all tables keep it in the units of s/m^(1/3).
 
     Examples
     --------
@@ -483,7 +522,7 @@ def V_Manning(Rh, S, n):
     .. [2] Cengel, Yunus, and John Cimbala. Fluid Mechanics: Fundamentals and
        Applications. Boston: McGraw Hill Higher Education, 2006.
     '''
-    return Rh**(2/3.)*S**0.5/n
+    return Rh**(2.0/3.)*sqrt(S)/n
 
 
 def n_Manning_to_C_Chezy(n, Rh):
@@ -599,7 +638,7 @@ def V_Chezy(Rh, S, C):
        Applications. Boston: McGraw Hill Higher Education, 2006.
     .. [3] Chow, Ven Te. Open-Channel Hydraulics. New York: McGraw-Hill, 1959.
     '''
-    return C*(S*Rh)**0.5
+    return C*sqrt(S*Rh)
 
 
 
@@ -610,6 +649,7 @@ def V_Chezy(Rh, S, C):
 
 
 ### Manning coefficients
+# Tuple of minimum, average, maximum
 
 n_closed_conduit = {
     'Brass': {
