@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
-'''Chemical Engineering Design Library (ChEDL). Utilities for process modeling.
-Copyright (C) 2016, Caleb Bell <Caleb.Andrew.Bell@gmail.com>
+"""Chemical Engineering Design Library (ChEDL). Utilities for process modeling.
+Copyright (C) 2016, 2017, 2018, 2020 Caleb Bell <Caleb.Andrew.Bell@gmail.com>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -18,13 +18,52 @@ FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-SOFTWARE.'''
+SOFTWARE.
+
+This module contains correlations for calculating the pressure drop across
+a packed bed. Several correlations for void fraction are also included.
+
+For reporting bugs, adding feature requests, or submitting pull requests,
+please use the `GitHub issue tracker <https://github.com/CalebBell/fluids/>`_
+or contact the author at Caleb.Andrew.Bell@gmail.com.
+
+.. contents:: :local:
+
+Packed Bed Correlation Interfaces
+---------------------------------
+.. autofunction:: dP_packed_bed
+.. autofunction:: dP_packed_bed_methods
+
+Packed Bed Correlations
+-----------------------
+.. autofunction:: Ergun
+.. autofunction:: Kuo_Nydegger
+.. autofunction:: Jones_Krier
+.. autofunction:: Carman
+.. autofunction:: Hicks
+.. autofunction:: Brauer
+.. autofunction:: KTA
+.. autofunction:: Erdim_Akgiray_Demir
+.. autofunction:: Fahien_Schriver
+.. autofunction:: Tallmadge
+.. autofunction:: Idelchik
+.. autofunction:: Harrison_Brunner_Hecker
+.. autofunction:: Montillet_Akkari_Comiti
+.. autofunction:: Guo_Sun
+
+Voidage Correlations
+--------------------
+.. autofunction:: voidage_Benyahia_Oneil
+.. autofunction:: voidage_Benyahia_Oneil_spherical
+.. autofunction:: voidage_Benyahia_Oneil_cylindrical
+
+"""
 
 from __future__ import division
-from math import exp, pi
+from math import exp, pi, sqrt
 
-__all__ = ['dP_packed_bed', 'Ergun', 'Kuo_Nydegger', 'Jones_Krier', 'Carman', 'Hicks',
-           'Brauer', 'KTA', 'Erdim_Akgiray_Demir', 'Fahien_Schriver', 
+__all__ = ['dP_packed_bed', 'dP_packed_bed_methods', 'Ergun', 'Kuo_Nydegger', 'Jones_Krier', 'Carman', 'Hicks',
+           'Brauer', 'KTA', 'Erdim_Akgiray_Demir', 'Fahien_Schriver',
            'Tallmadge', 'Idelchik',
            'Harrison_Brunner_Hecker', 'Montillet_Akkari_Comiti', 'Guo_Sun',
             'voidage_Benyahia_Oneil',
@@ -32,7 +71,7 @@ __all__ = ['dP_packed_bed', 'Ergun', 'Kuo_Nydegger', 'Jones_Krier', 'Carman', 'H
 
 
 
-def Ergun(dp, voidage, vs, rho, mu, L=1):
+def Ergun(dp, voidage, vs, rho, mu, L=1.0):
     r'''Calculates pressure drop across a packed bed of spheres using a
     correlation developed in [1]_, as shown in [2]_ and [3]_. Eighteenth most
     accurate correlation overall in the review of [2]_.
@@ -70,7 +109,7 @@ def Ergun(dp, voidage, vs, rho, mu, L=1):
     voidage : float
         Void fraction of bed packing [-]
     vs : float
-        Superficial velocity of the fluid (volumetric flow rate/cross-sectional 
+        Superficial velocity of the fluid (volumetric flow rate/cross-sectional
         area)[m/s]
     rho : float
         Density of the fluid [kg/m^3]
@@ -114,7 +153,7 @@ def Ergun(dp, voidage, vs, rho, mu, L=1):
     return fp*rho*vs**2*L/dp
 
 
-def Kuo_Nydegger(dp, voidage, vs, rho, mu, L=1):
+def Kuo_Nydegger(dp, voidage, vs, rho, mu, L=1.0):
     r'''Calculates pressure drop across a packed bed of spheres using a
     correlation developed in [1]_, as shown in [2]_ and [3]. Thirty-eighth most
     accurate correlation overall in the review of [2]_.
@@ -136,7 +175,7 @@ def Kuo_Nydegger(dp, voidage, vs, rho, mu, L=1):
     voidage : float
         Void fraction of bed packing [-]
     vs : float
-        Superficial velocity of the fluid (volumetric flow rate/cross-sectional 
+        Superficial velocity of the fluid (volumetric flow rate/cross-sectional
         area)[m/s]
     rho : float
         Density of the fluid [kg/m^3]
@@ -179,14 +218,14 @@ def Kuo_Nydegger(dp, voidage, vs, rho, mu, L=1):
     return fp*rho*vs**2*L/dp
 
 
-def Tallmadge(dp, voidage, vs, rho, mu, L=1):
+def Tallmadge(dp, voidage, vs, rho, mu, L=1.0):
     r'''Calculates pressure drop across a packed bed of spheres using a
-    correlation developed in [1]_, as shown in [2]_ and [3]. 
+    correlation developed in [1]_, as shown in [2]_ and [3].
 
     .. math::
         f_p = \left(150 + 4.2\left(\frac{Re}{1-\epsilon}\right)^{5/6} \right)
         \frac{(1-\epsilon)^2}{\epsilon^3 Re}
-        
+
     .. math::
         f_p = \frac{\Delta P d_p}{\rho v_s^2 L}
 
@@ -200,7 +239,7 @@ def Tallmadge(dp, voidage, vs, rho, mu, L=1):
     voidage : float
         Void fraction of bed packing [-]
     vs : float
-        Superficial velocity of the fluid (volumetric flow rate/cross-sectional 
+        Superficial velocity of the fluid (volumetric flow rate/cross-sectional
         area)[m/s]
     rho : float
         Density of the fluid [kg/m^3]
@@ -226,7 +265,7 @@ def Tallmadge(dp, voidage, vs, rho, mu, L=1):
 
     References
     ----------
-    .. [1] Tallmadge, J. A. "Packed Bed Pressure Drop-an Extension to Higher 
+    .. [1] Tallmadge, J. A. "Packed Bed Pressure Drop-an Extension to Higher
        Reynolds Numbers." AIChE Journal 16, no. 6 (November 1, 1970): 1092-93.
     .. [2] Erdim, Esra, Ömer Akgiray, and İbrahim Demir. "A Revisit of Pressure
        Drop-Flow Rate Correlations for Packed Beds of Spheres." Powder
@@ -242,7 +281,7 @@ def Tallmadge(dp, voidage, vs, rho, mu, L=1):
     return fp*rho*vs**2*L/dp
 
 
-def Jones_Krier(dp, voidage, vs, rho, mu, L=1):
+def Jones_Krier(dp, voidage, vs, rho, mu, L=1.0):
     r'''Calculates pressure drop across a packed bed of spheres using a
     correlation developed in [1]_, also shown in [2]_. Tenth most accurate
     correlation overall in the review of [2]_.
@@ -264,7 +303,7 @@ def Jones_Krier(dp, voidage, vs, rho, mu, L=1):
     voidage : float
         Void fraction of bed packing [-]
     vs : float
-        Superficial velocity of the fluid (volumetric flow rate/cross-sectional 
+        Superficial velocity of the fluid (volumetric flow rate/cross-sectional
         area)[m/s]
     rho : float
         Density of the fluid [kg/m^3]
@@ -304,7 +343,7 @@ def Jones_Krier(dp, voidage, vs, rho, mu, L=1):
     return fp*rho*vs**2*L/dp
 
 
-def Carman(dp, voidage, vs, rho, mu, L=1):
+def Carman(dp, voidage, vs, rho, mu, L=1.0):
     r'''Calculates pressure drop across a packed bed of spheres using a
     correlation developed in [1]_, as shown in [2]_. Fifth most accurate
     correlation overall in the review of [2]_. Also shown in [3]_.
@@ -326,7 +365,7 @@ def Carman(dp, voidage, vs, rho, mu, L=1):
     voidage : float
         Void fraction of bed packing [-]
     vs : float
-        Superficial velocity of the fluid (volumetric flow rate/cross-sectional 
+        Superficial velocity of the fluid (volumetric flow rate/cross-sectional
         area)[m/s]
     rho : float
         Density of the fluid [kg/m^3]
@@ -367,7 +406,7 @@ def Carman(dp, voidage, vs, rho, mu, L=1):
     return fp*rho*vs**2*L/dp
 
 
-def Hicks(dp, voidage, vs, rho, mu, L=1):
+def Hicks(dp, voidage, vs, rho, mu, L=1.0):
     r'''Calculates pressure drop across a packed bed of spheres using a
     correlation developed in [1]_, as shown in [2]_. Twenty-third most accurate
     correlation overall in the review of [2]_. Also shown in [3]_.
@@ -388,7 +427,7 @@ def Hicks(dp, voidage, vs, rho, mu, L=1):
     voidage : float
         Void fraction of bed packing [-]
     vs : float
-        Superficial velocity of the fluid (volumetric flow rate/cross-sectional 
+        Superficial velocity of the fluid (volumetric flow rate/cross-sectional
         area)[m/s]
     rho : float
         Density of the fluid [kg/m^3]
@@ -430,7 +469,7 @@ def Hicks(dp, voidage, vs, rho, mu, L=1):
     return fp*rho*vs**2*L/dp
 
 
-def Brauer(dp, voidage, vs, rho, mu, L=1):
+def Brauer(dp, voidage, vs, rho, mu, L=1.0):
     r'''Calculates pressure drop across a packed bed of spheres using a
     correlation developed in [1]_, as shown in [2]_. Seventh most accurate
     correlation overall in the review of [2]_. Also shown in [3]_.
@@ -452,7 +491,7 @@ def Brauer(dp, voidage, vs, rho, mu, L=1):
     voidage : float
         Void fraction of bed packing [-]
     vs : float
-        Superficial velocity of the fluid (volumetric flow rate/cross-sectional 
+        Superficial velocity of the fluid (volumetric flow rate/cross-sectional
         area)[m/s]
     rho : float
         Density of the fluid [kg/m^3]
@@ -468,7 +507,7 @@ def Brauer(dp, voidage, vs, rho, mu, L=1):
 
     Notes
     -----
-    Original has not been reviewed.
+    The original article [1]_ has not been reviewed.
     In [2]_, is stated as for a range of :math:`2 < Re_{Erg} < 20,000`.
     In [3]_, is stated as for a range of :math:`0.01 < Re_{Erg} < 40,000`.
 
@@ -484,7 +523,7 @@ def Brauer(dp, voidage, vs, rho, mu, L=1):
     .. [2] Erdim, Esra, Ömer Akgiray, and İbrahim Demir. "A Revisit of Pressure
        Drop-Flow Rate Correlations for Packed Beds of Spheres." Powder
        Technology 283 (October 2015): 488-504. doi:10.1016/j.powtec.2015.06.017.
-    .. [2] Allen, K. G., T. W. von Backstrom, and D. G. Kroger. "Packed Bed
+    .. [3] Allen, K. G., T. W. von Backstrom, and D. G. Kroger. "Packed Bed
        Pressure Drop Dependence on Particle Shape, Size Distribution, Packing
        Arrangement and Roughness." Powder Technology 246 (September 2013):
        590-600. doi:10.1016/j.powtec.2013.06.022.
@@ -494,7 +533,7 @@ def Brauer(dp, voidage, vs, rho, mu, L=1):
     return fp*rho*vs**2*L/dp
 
 
-def KTA(dp, voidage, vs, rho, mu, L=1):
+def KTA(dp, voidage, vs, rho, mu, L=1.0):
     r'''Calculates pressure drop across a packed bed of spheres using a
     correlation developed in [1]_, as shown in [2]_. Third most accurate
     correlation overall in the review of [2]_.
@@ -516,7 +555,7 @@ def KTA(dp, voidage, vs, rho, mu, L=1):
     voidage : float
         Void fraction of bed packing [-]
     vs : float
-        Superficial velocity of the fluid (volumetric flow rate/cross-sectional 
+        Superficial velocity of the fluid (volumetric flow rate/cross-sectional
         area)[m/s]
     rho : float
         Density of the fluid [kg/m^3]
@@ -533,7 +572,7 @@ def KTA(dp, voidage, vs, rho, mu, L=1):
     Notes
     -----
     Developed for gas flow through pebbles in nuclear reactors.
-    
+
     In [2]_, stated as for a range of :math:`1 < RE_{Erg} <100,000`.
     In [1]_, a limit on porosity is stated as :math:`0.36 < \epsilon < 0.42`.
 
@@ -557,7 +596,7 @@ def KTA(dp, voidage, vs, rho, mu, L=1):
     return fp*rho*vs**2*L/dp
 
 
-def Erdim_Akgiray_Demir(dp, voidage, vs, rho, mu, L=1):
+def Erdim_Akgiray_Demir(dp, voidage, vs, rho, mu, L=1.0):
     r'''Calculates pressure drop across a packed bed of spheres using a
     correlation developed in [1]_, claiming to be the best model to date.
 
@@ -577,7 +616,7 @@ def Erdim_Akgiray_Demir(dp, voidage, vs, rho, mu, L=1):
     voidage : float
         Void fraction of bed packing [-]
     vs : float
-        Superficial velocity of the fluid (volumetric flow rate/cross-sectional 
+        Superficial velocity of the fluid (volumetric flow rate/cross-sectional
         area)[m/s]
     rho : float
         Density of the fluid [kg/m^3]
@@ -616,7 +655,7 @@ def Erdim_Akgiray_Demir(dp, voidage, vs, rho, mu, L=1):
     return fv*(mu*vs*L/dp**2)*(1-voidage)**2/voidage**3
 
 
-def Fahien_Schriver(dp, voidage, vs, rho, mu, L=1):
+def Fahien_Schriver(dp, voidage, vs, rho, mu, L=1.0):
     r'''Calculates pressure drop across a packed bed of spheres using a
     correlation developed in [1]_, as shown in [2]_. Second most accurate
     correlation overall in the review of [2]_.
@@ -650,7 +689,7 @@ def Fahien_Schriver(dp, voidage, vs, rho, mu, L=1):
     voidage : float
         Void fraction of bed packing [-]
     vs : float
-        Superficial velocity of the fluid (volumetric flow rate/cross-sectional 
+        Superficial velocity of the fluid (volumetric flow rate/cross-sectional
         area)[m/s]
     rho : float
         Density of the fluid [kg/m^3]
@@ -691,7 +730,7 @@ def Fahien_Schriver(dp, voidage, vs, rho, mu, L=1):
     return fp*rho*vs**2*L/dp
 
 
-def Idelchik(dp, voidage, vs, rho, mu, L=1):
+def Idelchik(dp, voidage, vs, rho, mu, L=1.0):
     r'''Calculates pressure drop across a packed bed of spheres as in [2]_,
     originally in [1]_.
 
@@ -712,7 +751,7 @@ def Idelchik(dp, voidage, vs, rho, mu, L=1):
     voidage : float
         Void fraction of bed packing [-]
     vs : float
-        Superficial velocity of the fluid (volumetric flow rate/cross-sectional 
+        Superficial velocity of the fluid (volumetric flow rate/cross-sectional
         area)[m/s]
     rho : float
         Density of the fluid [kg/m^3]
@@ -747,7 +786,7 @@ def Idelchik(dp, voidage, vs, rho, mu, L=1):
        590-600. doi:10.1016/j.powtec.2013.06.022.
     '''
     Re = rho*vs*dp/mu/(1-voidage)
-    Re = (0.45/voidage**0.5)*Re
+    Re = (0.45/sqrt(voidage))*Re
     right = 0.765/voidage**4.2*(30./Re + 3./Re**0.7 + 0.3)
     left = dp/L/rho/vs**2
     return right/left
@@ -782,7 +821,7 @@ def Harrison_Brunner_Hecker(dp, voidage, vs, rho, mu, L=1, Dt=None):
     voidage : float
         Void fraction of bed packing [-]
     vs : float
-        Superficial velocity of the fluid (volumetric flow rate/cross-sectional 
+        Superficial velocity of the fluid (volumetric flow rate/cross-sectional
         area)[m/s]
     rho : float
         Density of the fluid [kg/m^3]
@@ -802,6 +841,7 @@ def Harrison_Brunner_Hecker(dp, voidage, vs, rho, mu, L=1, Dt=None):
     -----
     Uses data from other sources only. Correlation will underestimate pressure
     drop if tube diameter is not provided. Limits are specified in [1]_ as:
+
     .. math::
         0.72 < Re < 7700 \\
         8.3 < d_t/d_p < 50 \\
@@ -822,8 +862,8 @@ def Harrison_Brunner_Hecker(dp, voidage, vs, rho, mu, L=1, Dt=None):
        Technology 283 (October 2015): 488-504. doi:10.1016/j.powtec.2015.06.017.
     '''
     Re = dp*rho*vs/mu
-    if not Dt:
-        A, B = 1, 1
+    if Dt is None:
+        A, B = 1.0, 1.0
     else:
         A = (1 + pi*dp/(6*(1-voidage)*Dt))**2
         B = 1 - pi**2*dp/24/Dt*(1 - dp/(2*Dt))
@@ -850,7 +890,7 @@ def Montillet_Akkari_Comiti(dp, voidage, vs, rho, mu, L=1, Dt=None):
     voidage : float
         Void fraction of bed packing [-]
     vs : float
-        Superficial velocity of the fluid (volumetric flow rate/cross-sectional 
+        Superficial velocity of the fluid (volumetric flow rate/cross-sectional
         area)[m/s]
     rho : float
         Density of the fluid [kg/m^3]
@@ -896,26 +936,26 @@ def Montillet_Akkari_Comiti(dp, voidage, vs, rho, mu, L=1, Dt=None):
         a = 0.061
     else:
         a = 0.05
-    if not Dt or Dt/dp > 50:
+    if Dt is None or Dt/dp > 50:
         Dterm = 2.2
     else:
         Dterm = (Dt/dp)**0.2
-    right = a*Dterm*(1000./Re + 60/Re**0.5 + 12)
+    right = a*Dterm*(1000./Re + 60/sqrt(Re) + 12)
     left = dp/L/rho/vs**2*voidage**3/(1-voidage)
     return right/left
 
 
-def Guo_Sun(dp, voidage, vs, rho, mu, Dt, L=1):
+def Guo_Sun(dp, voidage, vs, rho, mu, Dt, L=1.0):
     r'''Calculates pressure drop across a packed bed of spheres using a
-    correlation developed in [1]_. This is valid for highly-packed particles 
-    at particle/tube diameter ratios between 2 and 3, where a ring packing 
+    correlation developed in [1]_. This is valid for highly-packed particles
+    at particle/tube diameter ratios between 2 and 3, where a ring packing
     structure occurs. If a packing ratio is so low, it is important to use this
-    model because in some cases its predictions are as low as half those of 
+    model because in some cases its predictions are as low as half those of
     other models!
 
     .. math::
         f_v = 180 + \left(9.5374\frac{d_p}{D_t} - 2.8054\right)Re_{Erg}^{0.97}
-        
+
     .. math::
         f_v = \frac{\Delta P d_p^2}{\mu v_s L}\frac{\epsilon^3}{(1-\epsilon)^2}
 
@@ -929,7 +969,7 @@ def Guo_Sun(dp, voidage, vs, rho, mu, Dt, L=1):
     voidage : float
         Void fraction of bed packing [-]
     vs : float
-        Superficial velocity of the fluid (volumetric flow rate/cross-sectional 
+        Superficial velocity of the fluid (volumetric flow rate/cross-sectional
         area)[m/s]
     rho : float
         Density of the fluid [kg/m^3]
@@ -958,22 +998,23 @@ def Guo_Sun(dp, voidage, vs, rho, mu, Dt, L=1):
     --------
     >>> Guo_Sun(dp=14.2E-3, voidage=0.492, vs=0.6, rho=1E3, mu=1E-3, Dt=40.9E-3)
     42019.529911473706
-    
+
     References
     ----------
-    .. [1] Guo, Zehua, Zhongning Sun, Nan Zhang, Ming Ding, and Jiaqing Liu. 
-       "Pressure Drop in Slender Packed Beds with Novel Packing Arrangement." 
+    .. [1] Guo, Zehua, Zhongning Sun, Nan Zhang, Ming Ding, and Jiaqing Liu.
+       "Pressure Drop in Slender Packed Beds with Novel Packing Arrangement."
        Powder Technology 321 (November 2017): 286-92.
-       doi:10.1016/j.powtec.2017.08.024. 
+       doi:10.1016/j.powtec.2017.08.024.
     '''
-    #  2 < D/d < 3, particles in contact with the wall tend to form a highly ordered ring structure. 
+    #  2 < D/d < 3, particles in contact with the wall tend to form a highly ordered ring structure.
     Rem = dp*rho*vs/mu/(1-voidage)
-    fv = 180 + (9.5374*dp/Dt - 2.8054)*Rem**0.97
+    ratio = dp/Dt if Dt is not None else 3.5 # Never ran
+    fv = 180 + (9.5374*ratio - 2.8054)*Rem**0.97
     return fv*(mu*vs*L/dp**2)*(1-voidage)**2/voidage**3
 
 
 
-# Format: Nice nane : (formula, uses_dt)
+# Format: Nice name : (formula, uses_dt)
 packed_beds_correlations = {
 'Ergun': (Ergun, False),
 'Tallmadge': (Tallmadge, False),
@@ -983,16 +1024,69 @@ packed_beds_correlations = {
 'Hicks': (Hicks, False),
 'Brauer': (Brauer, False),
 'KTA': (KTA, False),
-'Erdim, Akgiray & Demir': (Erdim_Akgiray_Demir, False),
 'Fahien & Schriver': (Fahien_Schriver, False),
 'Idelchik': (Idelchik, False),
+'Erdim, Akgiray & Demir': (Erdim_Akgiray_Demir, False),
+
 'Harrison, Brunner & Hecker': (Harrison_Brunner_Hecker, True),
 'Montillet, Akkari & Comiti': (Montillet_Akkari_Comiti, True),
 'Guo, Sun, Zhang, Ding & Liu': (Guo_Sun, True)
 }
 
+def dP_packed_bed_methods(dp, voidage, vs, rho, mu, L=1.0, Dt=None, check_ranges=False):
+    r'''This function handles determining which pressure drop in a packed bed
+    correlation are suitable for the provided inputs.
+
+    Preferred correlations are 'Erdim, Akgiray & Demir' when tube
+    diameter is not provided, and 'Harrison, Brunner & Hecker' when tube
+    diameter is provided.
+
+    Examples
+    --------
+    >>> dP_packed_bed_methods(dp=8E-4, voidage=0.4, vs=1E-3, rho=1E3, mu=1E-3, L=1.0)[0]
+    'Erdim, Akgiray & Demir'
+    >>> dP_packed_bed_methods(dp=8E-4, voidage=0.4, vs=1E-3, rho=1E3, mu=1E-3, L=1, Dt=1e-2)[0]
+    'Harrison, Brunner & Hecker'
+
+    Parameters
+    ----------
+    dp : float
+        Particle diameter of spheres [m]
+    voidage : float
+        Void fraction of bed packing [-]
+    vs : float
+        Superficial velocity of the fluid (volumetric flow rate/cross-sectional
+        area) [m/s]
+    rho : float
+        Density of the fluid [kg/m^3]
+    mu : float
+        Viscosity of the fluid, [Pa*s]
+    L : float, optional
+        Length the fluid flows in the packed bed [m]
+    Dt : float, optional
+        Diameter of the tube, [m]
+    check_ranges : bool, optional
+        Added for Future use only
+
+    Returns
+    -------
+    methods : list
+        List of methods which can be used to calculate `dP` with the given inputs
+    '''
+    methods = []
+    if (dp is not None and voidage is not None and vs is not None
+        and rho is not None and mu is not None and L is not None):
+        if Dt is not None:
+            methods = ['Harrison, Brunner & Hecker', 'Montillet, Akkari & Comiti', 'Guo, Sun, Zhang, Ding & Liu']
+
+        methods.extend(['Erdim, Akgiray & Demir', 'Idelchik', 'Fahien & Schriver',
+                        'KTA', 'Brauer', 'Hicks', 'Carman', 'Jones & Krier', 'Kuo & Nydegger',
+                        'Tallmadge', 'Ergun'])
+    return methods
+
+
 def dP_packed_bed(dp, voidage, vs, rho, mu, L=1, Dt=None, sphericity=None,
-                  Method=None, AvailableMethods=False):
+                  Method=None):
     r'''This function handles choosing which pressure drop in a packed bed
     correlation is used. Automatically select which correlation
     to use if none is provided. Returns None if insufficient information is
@@ -1000,8 +1094,8 @@ def dP_packed_bed(dp, voidage, vs, rho, mu, L=1, Dt=None, sphericity=None,
 
     Preferred correlations are 'Erdim, Akgiray & Demir' when tube
     diameter is not provided, and 'Harrison, Brunner & Hecker' when tube
-    diameter is provided. If you are using a particles in a narrow tube 
-    between 2 and 3 particle diameters, expect higher than normal voidages 
+    diameter is provided. If you are using a particles in a narrow tube
+    between 2 and 3 particle diameters, expect higher than normal voidages
     (0.4-0.5) and used the method 'Guo, Sun, Zhang, Ding & Liu'.
 
     Examples
@@ -1020,7 +1114,7 @@ def dP_packed_bed(dp, voidage, vs, rho, mu, L=1, Dt=None, sphericity=None,
     voidage : float
         Void fraction of bed packing [-]
     vs : float
-        Superficial velocity of the fluid (volumetric flow rate/cross-sectional 
+        Superficial velocity of the fluid (volumetric flow rate/cross-sectional
         area) [m/s]
     rho : float
         Density of the fluid [kg/m^3]
@@ -1037,46 +1131,52 @@ def dP_packed_bed(dp, voidage, vs, rho, mu, L=1, Dt=None, sphericity=None,
     -------
     dP : float
         Pressure drop across the bed [Pa]
-    methods : list, only returned if AvailableMethods == True
-        List of methods which can be used to calculate `dP` with the given inputs
 
     Other Parameters
     ----------------
     Method : string, optional
         A string of the function name to use, as in the dictionary
         packed_beds_correlations
-    AvailableMethods : bool, optional
-        If True, function will consider which methods which can be used to
-        calculate `dP` with the given inputs and return them as a list
     '''
-    def list_methods():
-        methods = []
-        if all((dp, voidage, vs, rho, mu, L)):
-            for key, values in packed_beds_correlations.items():
-                if Dt or not values[1]:
-                    methods.append(key)
-        if 'Harrison, Brunner & Hecker' in methods:
-            methods.remove('Harrison, Brunner & Hecker')
-            methods.insert(0, 'Harrison, Brunner & Hecker')
-        elif 'Erdim, Akgiray & Demir' in methods:
-            methods.remove('Erdim, Akgiray & Demir')
-            methods.insert(0, 'Erdim, Akgiray & Demir')
-        return methods
 
-    if AvailableMethods:
-        return list_methods()
-    if not Method:
-        Method = list_methods()[0]
-
-    if dp and sphericity:
-        dp = dp*sphericity
-    if Method in packed_beds_correlations:
-        if packed_beds_correlations[Method][1]:
-            return packed_beds_correlations[Method][0](dp=dp, voidage=voidage, vs=vs, rho=rho, mu=mu, L=L, Dt=Dt)
-        else:
-            return packed_beds_correlations[Method][0](dp=dp, voidage=voidage, vs=vs, rho=rho, mu=mu, L=L)
+    if Method is None:
+        Method2 = 'Harrison, Brunner & Hecker' if Dt is not None else 'Erdim, Akgiray & Demir'
     else:
-        raise Exception('Failure in in function')
+        Method2 = Method
+
+    if dp is not None and sphericity is not None:
+        dp = dp*sphericity
+
+    if Method2 == "Ergun":
+        return Ergun(dp=dp, voidage=voidage, vs=vs, rho=rho, mu=mu, L=L)
+    elif Method2 == "Tallmadge":
+        return Tallmadge(dp=dp, voidage=voidage, vs=vs, rho=rho, mu=mu, L=L)
+    elif Method2 == "Kuo & Nydegger":
+        return Kuo_Nydegger(dp=dp, voidage=voidage, vs=vs, rho=rho, mu=mu, L=L)
+    elif Method2 == "Jones & Krier":
+        return Jones_Krier(dp=dp, voidage=voidage, vs=vs, rho=rho, mu=mu, L=L)
+    elif Method2 == "Carman":
+        return Carman(dp=dp, voidage=voidage, vs=vs, rho=rho, mu=mu, L=L)
+    elif Method2 == "Hicks":
+        return Hicks(dp=dp, voidage=voidage, vs=vs, rho=rho, mu=mu, L=L)
+    elif Method2 == "Brauer":
+        return Brauer(dp=dp, voidage=voidage, vs=vs, rho=rho, mu=mu, L=L)
+    elif Method2 == "KTA":
+        return KTA(dp=dp, voidage=voidage, vs=vs, rho=rho, mu=mu, L=L)
+    elif Method2 == "Erdim, Akgiray & Demir":
+        return Erdim_Akgiray_Demir(dp=dp, voidage=voidage, vs=vs, rho=rho, mu=mu, L=L)
+    elif Method2 == "Fahien & Schriver":
+        return Fahien_Schriver(dp=dp, voidage=voidage, vs=vs, rho=rho, mu=mu, L=L)
+    elif Method2 == "Idelchik":
+        return Idelchik(dp=dp, voidage=voidage, vs=vs, rho=rho, mu=mu, L=L)
+    elif Method2 == "Harrison, Brunner & Hecker":
+        return Harrison_Brunner_Hecker(dp=dp, voidage=voidage, vs=vs, rho=rho, mu=mu, L=L, Dt=Dt)
+    elif Method2 == "Montillet, Akkari & Comiti":
+        return Montillet_Akkari_Comiti(dp=dp, voidage=voidage, vs=vs, rho=rho, mu=mu, L=L, Dt=Dt)
+    elif Method2 == "Guo, Sun, Zhang, Ding & Liu":
+        return Guo_Sun(dp=dp, voidage=voidage, vs=vs, rho=rho, mu=mu, L=L, Dt=Dt)
+    else:
+        raise ValueError('Unrecognized method')
 
 
 #import matplotlib.pyplot as plt
@@ -1101,7 +1201,7 @@ def dP_packed_bed(dp, voidage, vs, rho, mu, L=1, Dt=None, sphericity=None,
 ### Voidage correlations
 
 def voidage_Benyahia_Oneil(Dpe, Dt, sphericity):
-    r'''Calculates voidage of a bed of arbitraryily shaped uniform particles
+    r'''Calculates voidage of a bed of arbitrarily shaped uniform particles
     packed into a bed or tube of diameter `Dt`, with equivalent sphere diameter
     `Dp`. Shown in [1]_, and cited by various authors. Correlations exist
     also for spheres, solid cylinders, hollow cylinders, and 4-hole cylinders.
@@ -1114,7 +1214,7 @@ def voidage_Benyahia_Oneil(Dpe, Dt, sphericity):
     Parameters
     ----------
     Dpe : float
-        Equivalent spherical particle diameter (diameter of a sphere with the 
+        Equivalent spherical particle diameter (diameter of a sphere with the
         same volume), [m]
     Dt : float
         Diameter of the tube, [m]
@@ -1199,7 +1299,7 @@ def voidage_Benyahia_Oneil_cylindrical(Dpe, Dt, sphericity):
     Parameters
     ----------
     Dpe : float
-        Equivalent spherical particle diameter (diameter of a sphere with the 
+        Equivalent spherical particle diameter (diameter of a sphere with the
         same volume), [m]
     Dt : float
         Diameter of the tube, [m]
