@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-'''Chemical Engineering Design Library (ChEDL). Utilities for process modeling.
+"""Chemical Engineering Design Library (ChEDL). Utilities for process modeling.
 Copyright (C) 2016, Caleb Bell <Caleb.Andrew.Bell@gmail.com>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -20,11 +20,11 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 
-This module contains correlations and functions for calculating pressure drop 
+This module contains correlations and functions for calculating pressure drop
 from packings and demisters; separation efficiency of demisters; demister
 pressure drop; and demister geometry.
 
-For reporting bugs, adding feature requests, or submitting pull requests, 
+For reporting bugs, adding feature requests, or submitting pull requests,
 please use the `GitHub issue tracker <https://github.com/CalebBell/fluids/>`_
 or contact the author at Caleb.Andrew.Bell@gmail.com.
 
@@ -55,12 +55,12 @@ Demister Geometry
 -----------------
 .. autofunction:: fluids.packed_tower.voidage_experimental
 .. autofunction:: fluids.packed_tower.specific_area_mesh
-'''
+"""
 
 from __future__ import division
-from math import log
+from math import log, sqrt
 from fluids.constants import g, pi
-from fluids.numerics import newton, newton_system
+from fluids.numerics import secant, newton_system, solve_2_direct, numpy as np
 
 __all__ = ['voidage_experimental', 'specific_area_mesh',
 'Stichlmair_dry', 'Stichlmair_wet', 'Stichlmair_flood', 'Robbins',
@@ -68,10 +68,9 @@ __all__ = ['voidage_experimental', 'specific_area_mesh',
 'dP_demister_dry_Setekleiv_Svendsen',
 'dP_demister_wet_ElDessouky', 'separation_demister_ElDessouky']
 
-
 ### Demister
 
-def dP_demister_dry_Setekleiv_Svendsen(S, voidage, vs, rho, mu, L=1):
+def dP_demister_dry_Setekleiv_Svendsen(S, voidage, vs, rho, mu, L=1.0):
     r'''Calculates dry pressure drop across a demister, using the
     correlation in [1]_. This model is for dry demisters with no holdup only.
 
@@ -123,7 +122,7 @@ def dP_demister_dry_Setekleiv_Svendsen(S, voidage, vs, rho, mu, L=1):
     return right*rho*vs**2/voidage**2
 
 
-def dP_demister_dry_Setekleiv_Svendsen_lit(S, voidage, vs, rho, mu, L=1):
+def dP_demister_dry_Setekleiv_Svendsen_lit(S, voidage, vs, rho, mu, L=1.0):
     r'''Calculates dry pressure drop across a demister, using the
     correlation in [1]_. This model is for dry demisters with no holdup only.
     Developed with literature data included as well as their own experimental
@@ -162,7 +161,7 @@ def dP_demister_dry_Setekleiv_Svendsen_lit(S, voidage, vs, rho, mu, L=1):
 
     Examples
     --------
-    >>> dP_demister_dry_Setekleiv_Svendsen_lit(S=250, voidage=.983, vs=1.2, rho=10, mu=3E-5, L=1)
+    >>> dP_demister_dry_Setekleiv_Svendsen_lit(S=250, voidage=.983, vs=1.2, rho=10, mu=3E-5, L=1.0)
     209.083848658307
 
     References
@@ -177,14 +176,14 @@ def dP_demister_dry_Setekleiv_Svendsen_lit(S, voidage, vs, rho, mu, L=1):
     return right*rho*vs**2/voidage**2
 
 
-def dP_demister_wet_ElDessouky(vs, voidage, d_wire, L=1):
+def dP_demister_wet_ElDessouky(vs, voidage, d_wire, L=1.0):
     r'''Calculates wet pressure drop across a demister, using the
     correlation in [1]_. Uses only their own experimental data.
-    
+
     .. math::
         \frac{\Delta P}{L} = 0.002357(1-\epsilon)^{0.375798}(V)^{0.81317}
         (d_w)^{-1.56114147}
-        
+
     Parameters
     ----------
     vs : float
@@ -211,30 +210,30 @@ def dP_demister_wet_ElDessouky(vs, voidage, d_wire, L=1):
 
     The correlation in [1]_ was presented as follows, with wire diameter in
     units of mm, density in kg/m^3, V in m/s, and dP in Pa/m.
-    
+
     .. math::
         \Delta P = 3.88178(\rho_{mesh})^{0.375798}(V)^{0.81317}
         (d_w)^{-1.56114147}
-    
+
     Here, the correlation is converted to base SI units and to use voidage;
-    not all demisters are stainless steel as in [1]_. A density of 7999 kg/m^3 
+    not all demisters are stainless steel as in [1]_. A density of 7999 kg/m^3
     was used in the conversion.
-    
-    In [1]_, V ranged from 0.98-7.5 m/s, rho from 80.317-208.16 kg/m^3, depth 
-    from 100 to 200 mm, wire diameter of 0.2mm to 0.32 mm, and particle 
+
+    In [1]_, V ranged from 0.98-7.5 m/s, rho from 80.317-208.16 kg/m^3, depth
+    from 100 to 200 mm, wire diameter of 0.2mm to 0.32 mm, and particle
     diameter from 1 to 5 mm.
-    
+
 
     Examples
     --------
     >>> dP_demister_wet_ElDessouky(6, 0.978, 0.00032)
     688.9216420105029
-    
+
     References
     ----------
-    .. [1] El-Dessouky, Hisham T, Imad M Alatiqi, Hisham M Ettouney, and Noura 
-       S Al-Deffeeri. "Performance of Wire Mesh Mist Eliminator." Chemical 
-       Engineering and Processing: Process Intensification 39, no. 2 (March 
+    .. [1] El-Dessouky, Hisham T, Imad M Alatiqi, Hisham M Ettouney, and Noura
+       S Al-Deffeeri. "Performance of Wire Mesh Mist Eliminator." Chemical
+       Engineering and Processing: Process Intensification 39, no. 2 (March
        2000): 129-39. doi:10.1016/S0255-2701(99)00033-1.
     '''
     return L*0.002356999643727531*(1-voidage)**0.375798*vs**0.81317*d_wire**-1.56114147
@@ -243,11 +242,11 @@ def dP_demister_wet_ElDessouky(vs, voidage, d_wire, L=1):
 def separation_demister_ElDessouky(vs, voidage, d_wire, d_drop):
     r'''Calculates droplet removal by a demister as a fraction from 0 to 1,
     using the correlation in [1]_. Uses only their own experimental data.
-    
+
     .. math::
         \eta = 0.85835(d_w)^{-0.28264}(1-\epsilon)^{0.099625}(V)^{0.106878}
         (d_p)^{0.383197}
-        
+
     Parameters
     ----------
     vs : float
@@ -269,35 +268,35 @@ def separation_demister_ElDessouky(vs, voidage, d_wire, d_drop):
     No dependency on the liquid properties is included here. Because of the
     exponential nature of the correlation, for smaller diameters separation
     quickly lowers. This correlation can predict a separation larger than 1
-    for higher velocities, lower voidages, lower wire diameters, and large 
+    for higher velocities, lower voidages, lower wire diameters, and large
     droplet sizes. This function truncates these larger values to 1.
-    
+
     The correlation in [1]_ was presented as follows, with wire diameter in
     units of mm, density in kg/m^3, V in m/s, separation in %, and particle
     diameter in mm.
-    
+
     .. math::
         \eta = 17.5047(d_w)^{-0.28264}(\rho_{mesh})^{0.099625}(V)^{0.106878}
         (d_p)^{0.383197}
-    
+
     Here, the correlation is converted to base SI units and to use voidage;
-    not all demisters are stainless steel as in [1]_. A density of 7999 kg/m^3 
+    not all demisters are stainless steel as in [1]_. A density of 7999 kg/m^3
     was used in the conversion.
-    
-    In [1]_, V ranged from 0.98-7.5 m/s, rho from 80.317-208.16 kg/m^3, depth 
-    from 100 to 200 mm, wire diameter of 0.2 mm to 0.32 mm, and particle 
+
+    In [1]_, V ranged from 0.98-7.5 m/s, rho from 80.317-208.16 kg/m^3, depth
+    from 100 to 200 mm, wire diameter of 0.2 mm to 0.32 mm, and particle
     diameter from 1 to 5 mm.
-    
+
     Examples
     --------
     >>> separation_demister_ElDessouky(1.35, 0.974, 0.0002, 0.005)
     0.8982892997640582
-    
+
     References
     ----------
-    .. [1] El-Dessouky, Hisham T, Imad M Alatiqi, Hisham M Ettouney, and Noura 
-       S Al-Deffeeri. "Performance of Wire Mesh Mist Eliminator." Chemical 
-       Engineering and Processing: Process Intensification 39, no. 2 (March 
+    .. [1] El-Dessouky, Hisham T, Imad M Alatiqi, Hisham M Ettouney, and Noura
+       S Al-Deffeeri. "Performance of Wire Mesh Mist Eliminator." Chemical
+       Engineering and Processing: Process Intensification 39, no. 2 (March
        2000): 129-39. doi:10.1016/S0255-2701(99)00033-1.
     '''
     eta = 0.858352355761947*d_wire**-0.28264*(1-voidage)**0.099625*vs**0.106878*d_drop**0.383197
@@ -442,7 +441,7 @@ def Stichlmair_dry(Vg, rhog, mug, voidage, specific_area, C1, C2, C3, H=1.):
     Examples
     --------
     >>> Stichlmair_dry(Vg=0.4, rhog=5., mug=5E-5, voidage=0.68,
-    ... specific_area=260., C1=32., C2=7, C3=1)
+    ... specific_area=260., C1=32., C2=7.0, C3=1.0)
     236.80904286559885
 
     References
@@ -454,11 +453,16 @@ def Stichlmair_dry(Vg, rhog, mug, voidage, specific_area, C1, C2, C3, H=1.):
     '''
     dp = 6*(1-voidage)/specific_area
     Re = Vg*rhog*dp/mug
-    f0 = C1/Re + C2/Re**0.5 + C3
+    f0 = C1/Re + C2/sqrt(Re) + C3
     return 3/4.*f0*(1-voidage)/voidage**4.65*rhog*H/dp*Vg**2
 
 
-def Stichlmair_wet(Vg, Vl, rhog, rhol, mug, voidage, specific_area, C1, C2, C3, H=1):
+def _Stichlmair_wet_err(dP_irr, h0, c1, dP_dry, H, voidage, c):
+    hT = h0*(1.0 + 20.0*dP_irr*dP_irr*c1)
+    err = dP_dry/H*((1-voidage+hT)/(1.0 - voidage))**((2.0 + c)/3.)*(voidage/(voidage-hT))**4.65 -dP_irr/H
+    return err
+
+def Stichlmair_wet(Vg, Vl, rhog, rhol, mug, voidage, specific_area, C1, C2, C3, H=1.0):
     r'''Calculates dry pressure drop across a packed column, using the
     Stichlmair [1]_ correlation. Uses three regressed constants for each
     type of packing, and voidage and specific area. This model is for irrigated
@@ -538,7 +542,7 @@ def Stichlmair_wet(Vg, Vl, rhog, rhol, mug, voidage, specific_area, C1, C2, C3,
 
     >>> Stichlmair_wet(Vg=0.4, Vl = 5E-3, rhog=5., rhol=1200., mug=5E-5,
     ... voidage=0.68, specific_area=260., C1=32., C2=7., C3=1.)
-    539.8768237253518
+    539.876823725352
 
     References
     ----------
@@ -553,29 +557,27 @@ def Stichlmair_wet(Vg, Vl, rhog, rhol, mug, voidage, specific_area, C1, C2, C3,
     '''
     dp = 6.0*(1.0 - voidage)/specific_area
     Re = Vg*rhog*dp/mug
-    f0 = C1/Re + C2/Re**0.5 + C3
+    f0 = C1/Re + C2/sqrt(Re) + C3
     dP_dry = 3/4.*f0*(1-voidage)/voidage**4.65*rhog*H/dp*Vg*Vg
-    c = (-C1/Re - C2/(2*Re**0.5))/f0
+    c = (-C1/Re - C2/(2*sqrt(Re)))/f0
     Frl = Vl**2*specific_area/(g*voidage**4.65)
     h0 = 0.555*Frl**(1/3.)
-    def to_zero(dP_irr):
-        hT = h0*(1.0 + 20.0*(dP_irr/H/rhol/g)**2)
-        err = dP_dry/H*((1-voidage+hT)/(1.0 - voidage))**((2.0 + c)/3.)*(voidage/(voidage-hT))**4.65 -dP_irr/H
-        return err
-    return float(newton(to_zero, dP_dry))
+
+    c1 = 1.0/(H*rhol*g)
+    c1 *= c1
+    return secant(_Stichlmair_wet_err, dP_dry, args=(h0, c1, dP_dry, H, voidage, c))
 
 
 def _Stichlmair_flood_f(inputs, Vl, rhog, rhol, mug, voidage, specific_area,
                         C1, C2, C3, H):
-    '''Internal function which calculates the errors of the two Stichlmair
-    objective functions, and their jacobian.
-    '''
+    """Internal function which calculates the errors of the two Stichlmair
+    objective functions, and their jacobian."""
     Vg, dP_irr = float(inputs[0]), float(inputs[1])
     dp = 6.0*(1.0 - voidage)/specific_area
     Re = Vg*rhog*dp/mug
-    f0 = C1/Re + C2/Re**0.5 + C3
+    f0 = C1/Re + C2/sqrt(Re) + C3
     dP_dry = 0.75*f0*(1.0 - voidage)/voidage**4.65*rhog*H/dp*Vg*Vg
-    c = (-C1/Re - 0.5*C2*Re**-0.5)/f0
+    c = (-C1/Re - 0.5*C2*1.0/sqrt(Re))/f0
     Frl = Vl*Vl*specific_area/(g*voidage**4.65)
     h0 = 0.555*Frl**(1/3.)
     hT = h0*(1.0 + 20.0*(dP_irr/H/rhol/g)**2)
@@ -585,15 +587,14 @@ def _Stichlmair_flood_f(inputs, Vl, rhog, rhol, mug, voidage, specific_area,
     - 186.0*h0/(voidage - h0*(1.0 + 20.0*term)))
     return err1, err2
 
-
-def _Stichlmair_flood_f_and_jac(inputs, Vl, rhog, rhol, mug, voidage, 
+def _Stichlmair_flood_f_and_jac(inputs, Vl, rhog, rhol, mug, voidage,
                                 specific_area, C1, C2, C3, H):
-    '''Internal function which calculates the errors of the two Stichlmair
+    """Internal function which calculates the errors of the two Stichlmair
     objective functions, and their jacobian.
-    
+
     Derived using SymPy on the main flooding function.
-    '''
-    Vg, dP_irr = float(inputs[0]), float(inputs[1])
+    """
+    Vg, dP_irr = inputs[0], inputs[1]
     x0 = 1.0/H
     x1 = Vg*Vg
     x2 = voidage**(-4.65)
@@ -617,12 +618,12 @@ def _Stichlmair_flood_f_and_jac(inputs, Vl, rhog, rhol, mug, voidage,
     x20 = C1*mug*specific_area*x16*x17*x19
     x21 = 2.44948974278318*C2
     x22 = Vg*rhog/(mug*specific_area)
-    x23 = x21*(-x18*x22)**-0.5
+    x23 = x21*1.0/sqrt(-x18*x22)
     x24 = 6.0*C3 - x20 + x23
-    x25 = 1.0 - voidage 
+    x25 = 1.0 - voidage
     x26 = x14 + x25
     x27 = -x19*x26
-    x28 = 2.0*C1*mug*specific_area*x16*x17/x25 + x21*(x22*x25)**-0.5
+    x28 = 2.0*C1*mug*specific_area*x16*x17/x25 + x21*1.0/sqrt(x22*x25)
     x29 = 1.0/x24
     x30 = x28*x29
     x31 = x27**(-0.166666666666667*x30 + 0.666666666666667)
@@ -637,7 +638,7 @@ def _Stichlmair_flood_f_and_jac(inputs, Vl, rhog, rhol, mug, voidage,
     x40 = -4.0*x20 + x23 + x29*(-x23 + x39)*(x23 - x39)
     x41 = dP_irr*rhog*specific_area*x0*x1*x10*x12*x15*x2*x24*x31
     x42 = dP_irr*x10*x12*x4**0.666666666666667*x8
-    
+
     F1, F2, dF1_dVg, dF2_dVg, dF1_dP_irr, dF2_dP_irr = (
             -dP_irr*x0 + 0.0208333333333333*rhog*specific_area*x1*x15*x2*x24*x31,
              x32/x6 - 20646.0*x36*x5 - x38*x5*(2960.0 - 740.0*x28*x29),
@@ -645,11 +646,17 @@ def _Stichlmair_flood_f_and_jac(inputs, Vl, rhog, rhol, mug, voidage,
              x0*(430.125*x36*x41*x5 - 15.4166666666667*x38*x41*x5*(x30 - 4.0) - 1.0),
              -1.85*x16*x29*x40*x5/x26,
              3285600.0*x42*(-x30 + 4.0)*x38*x38- 91668240.0*x42*x36*x36 - 2.0*x32/(dP_irr*x6))
-    
-    return [F1, F2], [[dF1_dVg, dF2_dVg], [dF1_dP_irr, dF2_dP_irr]]
+
+    err = [0.0]*2
+    err[0] = F1
+    err[1] = F2
+
+    jac = [[dF1_dVg, dF2_dVg], [dF1_dP_irr, dF2_dP_irr]]# numba: delete
+#    jac = np.array([[dF1_dVg, dF2_dVg], [dF1_dP_irr, dF2_dP_irr]]) # numba: uncomment
+    return err, jac
+
 
 
-    
 def Stichlmair_flood(Vl, rhog, rhol, mug, voidage, specific_area, C1, C2, C3,
                      H=1.0):
     r'''Calculates gas rate for flooding of a packed column, using the
@@ -732,10 +739,12 @@ def Stichlmair_flood(Vl, rhog, rhol, mug, voidage, specific_area, C1, C2, C3,
        Packed Columns." Gas Separation & Purification 3, no. 1 (March 1989):
        19-28. doi:10.1016/0950-4214(89)80016-7.
     '''
-    guess =  [Vl*100., 1000.0]
+    guess = [0.0]*2
+    guess[0] = Vl*100.0
+    guess[1] = 1000.0
     return newton_system(_Stichlmair_flood_f_and_jac, x0=guess, jac=True,
-                         args=(Vl, rhog, rhol, mug, voidage, specific_area, C1, 
-                         C2, C3, H), ytol=1e-11)[0][0]
+                         args=(Vl, rhog, rhol, mug, voidage, specific_area, C1,
+                         C2, C3, H), ytol=1e-11, solve_func=solve_2_direct)[0][0]
 
 
 def Robbins(L, G, rhol, rhog, mul, H=1.0, Fpd=24.0):
@@ -802,9 +811,9 @@ def Robbins(L, G, rhol, rhog, mul, H=1.0, Fpd=24.0):
 
     C3 = 7.4E-8
     C4 = 2.7E-5
-    Fpd_root_term = (.05*Fpd)**0.5
+    Fpd_root_term = sqrt(.05*Fpd)
     Lf = L*(62.4/rhol)*Fpd_root_term*mul**0.1
-    Gf = G*(0.075/rhog)**0.5*Fpd_root_term
+    Gf = G*sqrt(0.075/rhog)*Fpd_root_term
     Gf2 = Gf*Gf
     C4LF_10_GF2_C3 = C3*Gf2*10.0**(C4*Lf)
     C4LF_10_GF2_C3_2 = C4LF_10_GF2_C3*C4LF_10_GF2_C3
