@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-'''Chemical Engineering Design Library (ChEDL). Utilities for process modeling.
+"""Chemical Engineering Design Library (ChEDL). Utilities for process modeling.
 Copyright (C) 2016, Caleb Bell <Caleb.Andrew.Bell@gmail.com>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -18,19 +18,70 @@ FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-SOFTWARE.'''
+SOFTWARE.
+
+This module contains correlations for calculating the efficiency of a pump,
+motor, or VFD. It also contains some functions for modeling the performance of
+a pump, and has been adapted to contain electrical information relevant to
+chemical engineering design.
+
+For reporting bugs, adding feature requests, or submitting pull requests,
+please use the `GitHub issue tracker <https://github.com/CalebBell/fluids/>`_
+or contact the author at Caleb.Andrew.Bell@gmail.com.
+
+.. contents:: :local:
+
+Pump Efficiency
+---------------
+.. autofunction :: Corripio_pump_efficiency
+
+Motor Efficiency
+----------------
+.. autofunction :: CSA_motor_efficiency
+.. autofunction :: motor_efficiency_underloaded
+.. autofunction :: Corripio_motor_efficiency
+
+VFD Efficiency
+--------------
+.. autofunction :: VFD_efficiency
+
+Pump Utilities
+--------------
+.. autofunction :: specific_speed
+.. autofunction :: specific_diameter
+.. autofunction :: speed_synchronous
+
+Motor Utilities
+---------------
+.. autofunction :: motor_round_size
+.. autodata :: nema_sizes
+.. autodata :: nema_sizes_hp
+
+Electrical Utilities
+--------------------
+.. autofunction :: current_ideal
+.. autoclass :: CountryPower
+.. autodata :: electrical_plug_types
+.. autodata :: voltages_1_phase_residential
+.. autodata :: voltages_3_phase
+.. autodata :: residential_power_frequencies
+.. autodata :: industrial_power
+.. autodata :: residential_power
+
+"""
 
 from __future__ import division
-from math import log
+from math import log, sqrt
 from fluids.constants import hp
 from fluids.numerics import interp, tck_interp2d_linear, bisplev
 
 __all__ = ['VFD_efficiency', 'CSA_motor_efficiency', 'motor_efficiency_underloaded',
 'Corripio_pump_efficiency', 'Corripio_motor_efficiency',
 'specific_speed', 'specific_diameter', 'speed_synchronous', 'nema_sizes',
-'nema_sizes_hp', 'motor_round_size', 'nema_min_P', 'nema_high_P', 'plug_types',
-'voltages_1_phase_residential', 'voltages_3_phase', 'frequencies',
-'residential_power', 'industrial_power', 'current_ideal']
+'nema_sizes_hp', 'motor_round_size', 'nema_min_P', 'nema_high_P', 'electrical_plug_types',
+'voltages_1_phase_residential', 'voltages_3_phase', 'residential_power_frequencies',
+'residential_power', 'industrial_power', 'current_ideal',
+'CountryPower']
 
 
 
@@ -129,10 +180,10 @@ VFD_efficiencies = [[0.31, 0.77, 0.86, 0.9, 0.91, 0.93, 0.94],
                     [0.61, 0.91, 0.95, 0.96, 0.96, 0.97, 0.97],
                     [0.61, 0.91, 0.95, 0.96, 0.96, 0.97, 0.97]]
 VFD_efficiency_loads = [0.016, 0.125, 0.25, 0.42, 0.5, 0.75, 1.0]
-VFD_efficiency_powers = [3.0, 5.0, 10.0, 20.0, 30.0, 50.0, 60.0, 75.0, 
+VFD_efficiency_powers = [3.0, 5.0, 10.0, 20.0, 30.0, 50.0, 60.0, 75.0,
                          100.0, 200.0, 400.0]
-VFD_efficiency_tck = tck_interp2d_linear(VFD_efficiency_loads, 
-                                         VFD_efficiency_powers, 
+VFD_efficiency_tck = tck_interp2d_linear(VFD_efficiency_loads,
+                                         VFD_efficiency_powers,
                                          VFD_efficiencies)
 
 
@@ -165,7 +216,7 @@ def VFD_efficiency(P, load=1):
     Table extends down to 3 hp and up to 400 hp; values outside these limits
     are rounded to the nearest known value. Values between standardized sizes
     are interpolated linearly. Load values extend down to 0.016.
-    
+
     The table used is for Pulse Width Modulation (PWM) VFDs.
 
     Examples
@@ -181,13 +232,13 @@ def VFD_efficiency(P, load=1):
        http://www.variablefrequencydrive.org/vfd-efficiency
     '''
     P = P/hp # convert to hp
-    if P < 3:
-        P = 3
-    elif P > 400:
-        P = 400
+    if P < 3.0:
+        P = 3.0
+    elif P > 400.0:
+        P = 400.0
     if load < 0.016:
         load = 0.016
-    return round(bisplev(load, P, VFD_efficiency_tck), 4)
+    return round(float(bisplev(load, P, VFD_efficiency_tck)), 4)
 
 
 nema_sizes_hp = [0.25, 0.3333333333333333, 0.5, 0.75, 1.0, 1.5, 2.0, 3.0, 4.0,
@@ -234,10 +285,10 @@ def motor_round_size(P):
     for P_actual in nema_sizes:
         if P_actual >= P:
             return P_actual
-    raise Exception('Required power is larger than can be provided with one motor')
+    raise ValueError('Required power is larger than can be provided with one motor')
 
 
-nema_high_P = [1, 1.5, 2, 3, 4, 5, 5.5, 7.5, 10, 15, 20, 25, 30, 40, 50, 60, 75, 100, 125, 150, 175, 200]
+nema_high_P = [1.0, 1.5, 2.0, 3.0, 4.0, 5.0, 5.5, 7.5, 10.0, 15.0, 20.0, 25.0, 30.0, 40.0, 50.0, 60.0, 75.0, 100.0, 125.0, 150.0, 175.0, 200.0]
 nema_high_full_open_2p = [0.77, 0.84, 0.855, 0.855, 0.865, 0.865, 0.865, 0.885, 0.895, 0.902, 0.91, 0.917, 0.917, 0.924, 0.93, 0.936, 0.936, 0.936, 0.941, 0.941, 0.95, 0.95]
 nema_high_full_open_4p = [0.855, 0.865, 0.865, 0.895, 0.895, 0.895, 0.895, 0.91, 0.917, 0.93, 0.93, 0.936, 0.941, 0.941, 0.945, 0.95, 0.95, 0.954, 0.954, 0.958, 0.958, 0.958]
 nema_high_full_open_6p = [0.825, 0.865, 0.875, 0.885, 0.895, 0.895, 0.895, 0.902, 0.917, 0.917, 0.924, 0.93, 0.936, 0.941, 0.941, 0.945, 0.945, 0.95, 0.95, 0.954, 0.954, 0.954]
@@ -246,7 +297,7 @@ nema_high_full_closed_4p = [0.855, 0.865, 0.865, 0.895, 0.895, 0.895, 0.895, 0.9
 nema_high_full_closed_6p = [0.825, 0.875, 0.885, 0.895, 0.895, 0.895, 0.895, 0.91, 0.91, 0.917, 0.917, 0.93, 0.93, 0.941, 0.941, 0.945, 0.945, 0.95, 0.95, 0.958, 0.958, 0.958]
 
 
-nema_min_P = [1, 1.5, 2, 3, 4, 5, 5.5, 7.5, 10, 15, 20, 25, 30, 40, 50, 60, 75, 100, 125, 150, 175, 200, 250, 300, 350, 400, 450, 500]
+nema_min_P = [1.0, 1.5, 2.0, 3.0, 4.0, 5.0, 5.5, 7.5, 10.0, 15.0, 20.0, 25.0, 30.0, 40.0, 50.0, 60.0, 75.0, 100.0, 125.0, 150.0, 175.0, 200.0, 250.0, 300.0, 350.0, 400.0, 450.0, 500.0]
 nema_min_full_open_2p  = [0.755, 0.825, 0.84, 0.84, 0.84, 0.855, 0.855, 0.875, 0.885, 0.895, 0.902, 0.91, 0.91, 0.917, 0.924, 0.93, 0.93, 0.93, 0.936, 0.936, 0.945, 0.945, 0.945, 0.95, 0.95, 0.954, 0.958, 0.958]
 nema_min_full_open_4p = [0.825, 0.84, 0.84, 0.865, 0.865, 0.875, 0.875, 0.885, 0.895, 0.91, 0.91, 0.917, 0.924, 0.93, 0.93, 0.936, 0.941, 0.941, 0.945, 0.95, 0.95, 0.95, 0.954, 0.954, 0.954, 0.954, 0.958, 0.958]
 nema_min_full_open_6p = [0.8, 0.84, 0.855, 0.865, 0.865, 0.875, 0.875, 0.885, 0.902, 0.902, 0.91, 0.917, 0.924, 0.93, 0.93, 0.936, 0.936, 0.941, 0.941, 0.945, 0.945, 0.945, 0.954, 0.954, 0.954, 0.954, 0.954, 0.954]
@@ -356,7 +407,7 @@ def CSA_motor_efficiency(P, closed=False, poles=2, high_efficiency=False):
                 efficiency = interp(P, nema_min_P, nema_min_full_open_6p)
             elif poles == 8:
                 efficiency = interp(P, nema_min_P, nema_min_full_open_8p)
-    
+
     return round(efficiency, 4)
 
 
@@ -408,13 +459,13 @@ def motor_efficiency_underloaded(P, load=0.5):
        Selection Handbook. 1993.
     '''
     P = P/hp
-    if P <=1:
+    if P <= 1.0:
         i = 0
-    elif P <= 5:
+    elif P <= 5.0:
         i = 1
-    elif P <= 10:
+    elif P <= 10.0:
         i = 2
-    elif P <= 25:
+    elif P <= 25.0:
         i = 3
     elif P <= 60:
         i = 4
@@ -464,7 +515,7 @@ def specific_speed(Q, H, n=3600.):
     ----------
     .. [1] HI 1.3 Rotodynamic Centrifugal Pumps for Design and Applications
     '''
-    return n*Q**0.5/H**0.75
+    return n*sqrt(Q)/H**0.75
 
 
 def specific_diameter(Q, H, D):
@@ -495,14 +546,14 @@ def specific_diameter(Q, H, D):
     Examples
     --------
     >>> specific_diameter(Q=0.1, H=10., D=0.1)
-    0.5623413251903491
+    0.5623413251903492
 
     References
     ----------
     .. [1] Green, Don, and Robert Perry. Perry's Chemical Engineers' Handbook,
        Eighth Edition. McGraw-Hill Professional, 2007.
     '''
-    return D*H**0.25*Q**-0.5
+    return D*sqrt(sqrt(H)/Q)
 
 
 def speed_synchronous(f, poles=2, phase=3):
@@ -593,17 +644,17 @@ def current_ideal(P, V, phase=3, PF=1):
        http://ecmweb.com/basics/calculating-single-and-3-phase-parameters.
     '''
     if phase not in [1, 3]:
-        raise Exception('Only 1 and 3 phase power supported')
+        raise ValueError('Only 1 and 3 phase power supported')
     if phase == 3:
-        return P/(V*3**0.5*PF)
+        return P/(V*sqrt(3)*PF)
     else:
         return P/(V*PF)
 
 
 class CountryPower(object):
-    '''Class to hold information on the residential or electrical data of
-    a country. Data from Wikipedia, obtained in 2017.
-    
+    """Class to hold information on the residential or electrical data of a
+    country. Data from Wikipedia, obtained in 2017.
+
     Parameters
     ----------
     plugs : tuple(str)
@@ -615,18 +666,17 @@ class CountryPower(object):
         The electrical frequency in use in the country, [Hz]
     country : str
         The name of the country, [-]
-        '''
+    """
     __slots__ = ('plugs', 'voltage', 'freq', 'country')
-    
+
     def __repr__(self):
-        return ('CountryPower(country="%s", voltage=%d, freq=%d, plugs=%s)' 
+        return ('CountryPower(country="%s", voltage=%s, freq=%d, plugs=%s)'
                 %(self.plugs, self.voltage, self.freq, self.country))
     def __init__(self, country, voltage, freq, plugs=None):
         self.plugs = plugs
         self.voltage = voltage
         self.freq = freq
         self.country = country
-        
 
 residential_power = {
     "at": CountryPower(plugs=('C', 'F'), voltage=230, freq=50, country="Austria"),
@@ -833,211 +883,229 @@ residential_power = {
     "ca": CountryPower(plugs=('A', 'B'), voltage=120, freq=60, country="Canada"),
     "cr": CountryPower(plugs=('A', 'B'), voltage=120, freq=60, country="Costa Rica")
 }
+'''Dictionary of country-code to CountryPower instances for residential use.'''
+
+CONST_380 = 380
+CONST_400 = 400
+CONST_415 = 415
+CONST_440 = 440
+CONST_480 = 480
+TUP_190 = (190,)
+TUP_208 = (208,)
+TUP_240 = (240,)
+TUP_380 = (CONST_380,)
+TUP_400 = (CONST_400,)
+TUP_415 = (CONST_415,)
 
 industrial_power = {
-    "at": CountryPower(voltage=(400,), freq=50, country='Austria'),
-    "bj": CountryPower(voltage=(380,), freq=50, country='Benin'),
-    "gh": CountryPower(voltage=(400,), freq=50, country='Ghana'),
-    "sc": CountryPower(voltage=(240,), freq=50, country='Seychelles'),
-    "bg": CountryPower(voltage=(400,), freq=50, country='Bulgaria'),
-    "me": CountryPower(voltage=(400,), freq=50, country='Montenegro'),
-    "fo": CountryPower(voltage=(400,), freq=50, country='Faeroe Islands'),
-    "iq": CountryPower(voltage=(400,), freq=50, country='Iraq'),
-    "ne": CountryPower(voltage=(380,), freq=50, country='Niger'),
-    "za": CountryPower(voltage=(400,), freq=50, country='South Africa'),
-    "az": CountryPower(voltage=(380,), freq=50, country='Azerbaijan'),
-    "so": CountryPower(voltage=(380,), freq=50, country='Somalia'),
-    "sn": CountryPower(voltage=(400,), freq=50, country='Senegal'),
-    "np": CountryPower(voltage=(400,), freq=50, country='Nepal'),
-    "sl": CountryPower(voltage=(400,), freq=50, country='Sierra Leone'),
-    "be": CountryPower(voltage=(400,), freq=50, country='Belgium'),
-    "vg": CountryPower(voltage=(190,), freq=60, country='British Virgin Islands'),
-    "bz": CountryPower(voltage=(190, 380), freq=60, country='Belize'),
+    "at": CountryPower(voltage=TUP_400, freq=50, country='Austria'),
+    "bj": CountryPower(voltage=TUP_380, freq=50, country='Benin'),
+    "gh": CountryPower(voltage=TUP_400, freq=50, country='Ghana'),
+    "sc": CountryPower(voltage=TUP_240, freq=50, country='Seychelles'),
+    "bg": CountryPower(voltage=TUP_400, freq=50, country='Bulgaria'),
+    "me": CountryPower(voltage=TUP_400, freq=50, country='Montenegro'),
+    "fo": CountryPower(voltage=TUP_400, freq=50, country='Faeroe Islands'),
+    "iq": CountryPower(voltage=TUP_400, freq=50, country='Iraq'),
+    "ne": CountryPower(voltage=TUP_380, freq=50, country='Niger'),
+    "za": CountryPower(voltage=TUP_400, freq=50, country='South Africa'),
+    "az": CountryPower(voltage=TUP_380, freq=50, country='Azerbaijan'),
+    "so": CountryPower(voltage=TUP_380, freq=50, country='Somalia'),
+    "sn": CountryPower(voltage=TUP_400, freq=50, country='Senegal'),
+    "np": CountryPower(voltage=TUP_400, freq=50, country='Nepal'),
+    "sl": CountryPower(voltage=TUP_400, freq=50, country='Sierra Leone'),
+    "be": CountryPower(voltage=TUP_400, freq=50, country='Belgium'),
+    "vg": CountryPower(voltage=TUP_190, freq=60, country='British Virgin Islands'),
+    "bz": CountryPower(voltage=(190, CONST_380), freq=60, country='Belize'),
     "tw": CountryPower(voltage=(220,), freq=60, country='Taiwan'),
-    "bf": CountryPower(voltage=(380,), freq=50, country='Burkina Faso'),
-    "ao": CountryPower(voltage=(380,), freq=50, country='Angola'),
-    "ee": CountryPower(voltage=(400,), freq=50, country='Estonia'),
-    "bs": CountryPower(voltage=(208,), freq=60, country='Bahamas'),
-    "ir": CountryPower(voltage=(400,), freq=50, country='Iran'),
+    "bf": CountryPower(voltage=TUP_380, freq=50, country='Burkina Faso'),
+    "ao": CountryPower(voltage=TUP_380, freq=50, country='Angola'),
+    "ee": CountryPower(voltage=TUP_400, freq=50, country='Estonia'),
+    "bs": CountryPower(voltage=TUP_208, freq=60, country='Bahamas'),
+    "ir": CountryPower(voltage=TUP_400, freq=50, country='Iran'),
     "sv": CountryPower(voltage=(200,), freq=60, country='El Salvador'),
-    "am": CountryPower(voltage=(400,), freq=50, country='Armenia'),
-    "is": CountryPower(voltage=(400,), freq=50, country='Iceland'),
-    "uy": CountryPower(voltage=(380,), freq=50, country='Uruguay'),
-    "mc": CountryPower(voltage=(400,), freq=50, country='Monaco'),
-    "jm": CountryPower(voltage=(190,), freq=50, country='Jamaica'),
-    "im": CountryPower(voltage=(415,), freq=50, country='Isle of Man'),
-    "dm": CountryPower(voltage=(400,), freq=50, country='Dominica'),
-    "mu": CountryPower(voltage=(400,), freq=50, country='Mauritius'),
-    "cz": CountryPower(voltage=(400,), freq=50, country='Czech Republic'),
-    "kh": CountryPower(voltage=(400,), freq=50, country='Cambodia'),
-    "cf": CountryPower(voltage=(380,), freq=50, country='Central African Republic'),
-    "se": CountryPower(voltage=(400,), freq=50, country='Sweden'),
-    "uz": CountryPower(voltage=(380,), freq=50, country='Uzbekistan'),
-    "sk": CountryPower(voltage=(400,), freq=50, country='Slovakia'),
-    "ky": CountryPower(voltage=(240,), freq=60, country='Cayman Islands'),
-    "tn": CountryPower(voltage=(400,), freq=50, country='Tunisia'),
-    "hu": CountryPower(voltage=(400,), freq=50, country='Hungary'),
-    "af": CountryPower(voltage=(380,), freq=50, country='Afghanistan'),
-    "tc": CountryPower(voltage=(240,), freq=60, country='Turks and Caicos Islands'),
-    "et": CountryPower(voltage=(380,), freq=50, country='Ethiopia'),
-    "sd": CountryPower(voltage=(400,), freq=50, country='Sudan'),
-    "ad": CountryPower(voltage=(400,), freq=50, country='Andorra'),
-    "hn": CountryPower(voltage=(208, 230, 240, 460, 480), freq=60, country='Honduras'),
-    "ls": CountryPower(voltage=(380,), freq=50, country='Lesotho'),
-    "na": CountryPower(voltage=(380,), freq=50, country='Namibia'),
-    "pl": CountryPower(voltage=(400,), freq=50, country='Poland'),
-    "bt": CountryPower(voltage=(400,), freq=50, country='Bhutan'),
-    "sa": CountryPower(voltage=(400,), freq=60, country='Saudi Arabia'),
+    "am": CountryPower(voltage=TUP_400, freq=50, country='Armenia'),
+    "is": CountryPower(voltage=TUP_400, freq=50, country='Iceland'),
+    "uy": CountryPower(voltage=TUP_380, freq=50, country='Uruguay'),
+    "mc": CountryPower(voltage=TUP_400, freq=50, country='Monaco'),
+    "jm": CountryPower(voltage=TUP_190, freq=50, country='Jamaica'),
+    "im": CountryPower(voltage=TUP_415, freq=50, country='Isle of Man'),
+    "dm": CountryPower(voltage=TUP_400, freq=50, country='Dominica'),
+    "mu": CountryPower(voltage=TUP_400, freq=50, country='Mauritius'),
+    "cz": CountryPower(voltage=TUP_400, freq=50, country='Czech Republic'),
+    "kh": CountryPower(voltage=TUP_400, freq=50, country='Cambodia'),
+    "cf": CountryPower(voltage=TUP_380, freq=50, country='Central African Republic'),
+    "se": CountryPower(voltage=TUP_400, freq=50, country='Sweden'),
+    "uz": CountryPower(voltage=TUP_380, freq=50, country='Uzbekistan'),
+    "sk": CountryPower(voltage=TUP_400, freq=50, country='Slovakia'),
+    "ky": CountryPower(voltage=TUP_240, freq=60, country='Cayman Islands'),
+    "tn": CountryPower(voltage=TUP_400, freq=50, country='Tunisia'),
+    "hu": CountryPower(voltage=TUP_400, freq=50, country='Hungary'),
+    "af": CountryPower(voltage=TUP_380, freq=50, country='Afghanistan'),
+    "tc": CountryPower(voltage=TUP_240, freq=60, country='Turks and Caicos Islands'),
+    "et": CountryPower(voltage=TUP_380, freq=50, country='Ethiopia'),
+    "sd": CountryPower(voltage=TUP_400, freq=50, country='Sudan'),
+    "ad": CountryPower(voltage=TUP_400, freq=50, country='Andorra'),
+    "hn": CountryPower(voltage=(208, 230, 240, 460, CONST_480), freq=60, country='Honduras'),
+    "ls": CountryPower(voltage=TUP_380, freq=50, country='Lesotho'),
+    "na": CountryPower(voltage=TUP_380, freq=50, country='Namibia'),
+    "pl": CountryPower(voltage=TUP_400, freq=50, country='Poland'),
+    "bt": CountryPower(voltage=TUP_400, freq=50, country='Bhutan'),
+    "sa": CountryPower(voltage=TUP_400, freq=60, country='Saudi Arabia'),
     "no": CountryPower(voltage=(230, 400), freq=50, country='Norway'),
-    "fk": CountryPower(voltage=(415,), freq=50, country='Falkland Islands'),
-    "ye": CountryPower(voltage=(400,), freq=50, country='Yemen'),
-    "gi": CountryPower(voltage=(400,), freq=50, country='Gibraltar'),
-    "md": CountryPower(voltage=(400,), freq=50, country='Moldova'),
-    "cn": CountryPower(voltage=(380,), freq=50, country='China'),
-    "gm": CountryPower(voltage=(400,), freq=50, country='Gambia'),
-    "sg": CountryPower(voltage=(400,), freq=50, country='Singapore'),
-    "tj": CountryPower(voltage=(380,), freq=50, country='Tajikistan'),
-    "gt": CountryPower(voltage=(208,), freq=60, country='Guatemala'),
-    "ma": CountryPower(voltage=(380,), freq=50, country='Morocco'),
-    "mv": CountryPower(voltage=(400,), freq=50, country='Maldives'),
-    "ga": CountryPower(voltage=(380,), freq=50, country='Gabon'),
-    "bo": CountryPower(voltage=(400,), freq=50, country='Bolivia'),
-    "ly": CountryPower(voltage=(400,), freq=50, country='Libya'),
-    "rw": CountryPower(voltage=(400,), freq=50, country='Rwanda'),
-    "cg": CountryPower(voltage=(400,), freq=50, country="People's Republic of Congo"),
-    "kz": CountryPower(voltage=(380,), freq=50, country='Kazakhstan'),
+    "fk": CountryPower(voltage=TUP_415, freq=50, country='Falkland Islands'),
+    "ye": CountryPower(voltage=TUP_400, freq=50, country='Yemen'),
+    "gi": CountryPower(voltage=TUP_400, freq=50, country='Gibraltar'),
+    "md": CountryPower(voltage=TUP_400, freq=50, country='Moldova'),
+    "cn": CountryPower(voltage=TUP_380, freq=50, country='China'),
+    "gm": CountryPower(voltage=TUP_400, freq=50, country='Gambia'),
+    "sg": CountryPower(voltage=TUP_400, freq=50, country='Singapore'),
+    "tj": CountryPower(voltage=TUP_380, freq=50, country='Tajikistan'),
+    "gt": CountryPower(voltage=TUP_208, freq=60, country='Guatemala'),
+    "ma": CountryPower(voltage=TUP_380, freq=50, country='Morocco'),
+    "mv": CountryPower(voltage=TUP_400, freq=50, country='Maldives'),
+    "ga": CountryPower(voltage=TUP_380, freq=50, country='Gabon'),
+    "bo": CountryPower(voltage=TUP_400, freq=50, country='Bolivia'),
+    "ly": CountryPower(voltage=TUP_400, freq=50, country='Libya'),
+    "rw": CountryPower(voltage=TUP_400, freq=50, country='Rwanda'),
+    "cg": CountryPower(voltage=TUP_400, freq=50, country="People's Republic of Congo"),
+    "kz": CountryPower(voltage=TUP_380, freq=50, country='Kazakhstan'),
     "jp": CountryPower(voltage=(200,), freq=50, country='Japan'),
     "co": CountryPower(voltage=(220, 440), freq=60, country='Colombia'),
-    "sm": CountryPower(voltage=(400,), freq=50, country='San Marino'),
-    "rs": CountryPower(voltage=(400,), freq=50, country='Serbia'),
-    "gw": CountryPower(voltage=(380,), freq=50, country='Guinea-Bissau'),
-    "kr": CountryPower(voltage=(380,), freq=60, country='South Korea'),
-    "py": CountryPower(voltage=(380,), freq=50, country='Paraguay'),
-    "lt": CountryPower(voltage=(400,), freq=50, country='Lithuania'),
-    "tr": CountryPower(voltage=(400,), freq=50, country='Turkey'),
-    "ss": CountryPower(voltage=(400,), freq=50, country='South Sudan'),
-    "ba": CountryPower(voltage=(400,), freq=50, country='Bosnia & Herzegovina'),
-    "vn": CountryPower(voltage=(380,), freq=50, country='Vietnam'),
+    "sm": CountryPower(voltage=TUP_400, freq=50, country='San Marino'),
+    "rs": CountryPower(voltage=TUP_400, freq=50, country='Serbia'),
+    "gw": CountryPower(voltage=TUP_380, freq=50, country='Guinea-Bissau'),
+    "kr": CountryPower(voltage=TUP_380, freq=60, country='South Korea'),
+    "py": CountryPower(voltage=TUP_380, freq=50, country='Paraguay'),
+    "lt": CountryPower(voltage=TUP_400, freq=50, country='Lithuania'),
+    "tr": CountryPower(voltage=TUP_400, freq=50, country='Turkey'),
+    "ss": CountryPower(voltage=TUP_400, freq=50, country='South Sudan'),
+    "ba": CountryPower(voltage=TUP_400, freq=50, country='Bosnia & Herzegovina'),
+    "vn": CountryPower(voltage=TUP_380, freq=50, country='Vietnam'),
     "do": CountryPower(voltage=(120, 208, 277, 480), freq=60, country='Dominican Republic'),
-    "pk": CountryPower(voltage=(400,), freq=50, country='Pakistan'),
-    "li": CountryPower(voltage=(400,), freq=50, country='Liechtenstein'),
-    "mz": CountryPower(voltage=(380,), freq=50, country='Mozambique'),
-    "au": CountryPower(voltage=(400,), freq=50, country='Australia'),
-    "ws": CountryPower(voltage=(400,), freq=50, country='Samoa'),
+    "pk": CountryPower(voltage=TUP_400, freq=50, country='Pakistan'),
+    "li": CountryPower(voltage=TUP_400, freq=50, country='Liechtenstein'),
+    "mz": CountryPower(voltage=TUP_380, freq=50, country='Mozambique'),
+    "au": CountryPower(voltage=TUP_400, freq=50, country='Australia'),
+    "ws": CountryPower(voltage=TUP_400, freq=50, country='Samoa'),
     "sr": CountryPower(voltage=(220, 400,), freq=60, country='Suriname'),
-    "mn": CountryPower(voltage=(400,), freq=50, country='Mongolia'),
-    "bw": CountryPower(voltage=(400,), freq=50, country='Botswana'),
-    "gb": CountryPower(voltage=(415,), freq=50, country='United Kingdom'),
-    "pg": CountryPower(voltage=(415,), freq=50, country='Papua New Guinea'),
-    "dj": CountryPower(voltage=(380,), freq=50, country='Djibouti'),
-    "th": CountryPower(voltage=(400,), freq=50, country='Thailand'),
-    "us": CountryPower(voltage=(120, 208, 277, 480, 120, 240, 240, 480), freq=60, country='United States of America'),
-    "gr": CountryPower(voltage=(400,), freq=50, country='Greece'),
-    "ug": CountryPower(voltage=(415,), freq=50, country='Uganda'),
-    "ie": CountryPower(voltage=(415,), freq=50, country='Ireland'),
-    "tg": CountryPower(voltage=(380,), freq=50, country='Togo'),
-    "td": CountryPower(voltage=(380,), freq=50, country='Chad'),
-    "la": CountryPower(voltage=(400,), freq=50, country='Laos'),
-    "sy": CountryPower(voltage=(380,), freq=50, country='Syria'),
-    "bm": CountryPower(voltage=(208,), freq=60, country='Bermuda'),
-    "il": CountryPower(voltage=(400,), freq=50, country='Israel'),
-    "nz": CountryPower(voltage=(400,), freq=50, country='New Zealand'),
-    "mg": CountryPower(voltage=(380,), freq=50, country='Madagascar'),
+    "mn": CountryPower(voltage=TUP_400, freq=50, country='Mongolia'),
+    "bw": CountryPower(voltage=TUP_400, freq=50, country='Botswana'),
+    "gb": CountryPower(voltage=TUP_415, freq=50, country='United Kingdom'),
+    "pg": CountryPower(voltage=TUP_415, freq=50, country='Papua New Guinea'),
+    "dj": CountryPower(voltage=TUP_380, freq=50, country='Djibouti'),
+    "th": CountryPower(voltage=TUP_400, freq=50, country='Thailand'),
+    "us": CountryPower(voltage=(120, 208, 277, 480, 120, 240, 240, CONST_480), freq=60, country='United States of America'),
+    "gr": CountryPower(voltage=TUP_400, freq=50, country='Greece'),
+    "ug": CountryPower(voltage=TUP_415, freq=50, country='Uganda'),
+    "ie": CountryPower(voltage=TUP_415, freq=50, country='Ireland'),
+    "tg": CountryPower(voltage=TUP_380, freq=50, country='Togo'),
+    "td": CountryPower(voltage=TUP_380, freq=50, country='Chad'),
+    "la": CountryPower(voltage=TUP_400, freq=50, country='Laos'),
+    "sy": CountryPower(voltage=TUP_380, freq=50, country='Syria'),
+    "bm": CountryPower(voltage=TUP_208, freq=60, country='Bermuda'),
+    "il": CountryPower(voltage=TUP_400, freq=50, country='Israel'),
+    "nz": CountryPower(voltage=TUP_400, freq=50, country='New Zealand'),
+    "mg": CountryPower(voltage=TUP_380, freq=50, country='Madagascar'),
     "ve": CountryPower(voltage=(120,), freq=60, country='Venezuela'),
-    "dk": CountryPower(voltage=(400,), freq=50, country='Denmark'),
-    "lb": CountryPower(voltage=(400,), freq=50, country='Lebanon'),
-    "kp": CountryPower(voltage=(380,), freq=50, country='North Korea'),
-    "vu": CountryPower(voltage=(400,), freq=50, country='Vanuatu'),
+    "dk": CountryPower(voltage=TUP_400, freq=50, country='Denmark'),
+    "lb": CountryPower(voltage=TUP_400, freq=50, country='Lebanon'),
+    "kp": CountryPower(voltage=TUP_380, freq=50, country='North Korea'),
+    "vu": CountryPower(voltage=TUP_400, freq=50, country='Vanuatu'),
     "cu": CountryPower(voltage=(190, 440), freq=60, country='Cuba'),
-    "kw": CountryPower(voltage=(415,), freq=50, country='Kuwait'),
-    "cd": CountryPower(voltage=(380,), freq=50, country='Democratic Republic of Congo'),
-    "nr": CountryPower(voltage=(415,), freq=50, country='Nauru'),
-    "si": CountryPower(voltage=(400,), freq=50, country='Slovenia'),
-    "mt": CountryPower(voltage=(400,), freq=50, country='Malta'),
-    "bd": CountryPower(voltage=(380,), freq=50, country='Bangladesh'),
-    "al": CountryPower(voltage=(400,), freq=50, country='Albania'),
-    "ec": CountryPower(voltage=(208,), freq=60, country='Ecuador'),
-    "gy": CountryPower(voltage=(190,), freq=60, country='Guyana'),
+    "kw": CountryPower(voltage=TUP_415, freq=50, country='Kuwait'),
+    "cd": CountryPower(voltage=TUP_380, freq=50, country='Democratic Republic of Congo'),
+    "nr": CountryPower(voltage=TUP_415, freq=50, country='Nauru'),
+    "si": CountryPower(voltage=TUP_400, freq=50, country='Slovenia'),
+    "mt": CountryPower(voltage=TUP_400, freq=50, country='Malta'),
+    "bd": CountryPower(voltage=TUP_380, freq=50, country='Bangladesh'),
+    "al": CountryPower(voltage=TUP_400, freq=50, country='Albania'),
+    "ec": CountryPower(voltage=TUP_208, freq=60, country='Ecuador'),
+    "gy": CountryPower(voltage=TUP_190, freq=60, country='Guyana'),
     "bb": CountryPower(voltage=(200,), freq=50, country='Barbados'),
-    "ke": CountryPower(voltage=(415,), freq=50, country='Kenya'),
-    "mx": CountryPower(voltage=(220, 480), freq=60, country='Mexico'),
-    "gn": CountryPower(voltage=(380,), freq=50, country='Guinea'),
-    "bi": CountryPower(voltage=(380,), freq=50, country='Burundi'),
-    "lv": CountryPower(voltage=(400,), freq=50, country='Latvia'),
-    "fj": CountryPower(voltage=(415,), freq=50, country='Fiji'),
-    "ci": CountryPower(voltage=(380,), freq=50, country='Côte d’Ivoire'),
+    "ke": CountryPower(voltage=TUP_415, freq=50, country='Kenya'),
+    "mx": CountryPower(voltage=(220, CONST_480), freq=60, country='Mexico'),
+    "gn": CountryPower(voltage=TUP_380, freq=50, country='Guinea'),
+    "bi": CountryPower(voltage=TUP_380, freq=50, country='Burundi'),
+    "lv": CountryPower(voltage=TUP_400, freq=50, country='Latvia'),
+    "fj": CountryPower(voltage=TUP_415, freq=50, country='Fiji'),
+    "ci": CountryPower(voltage=TUP_380, freq=50, country='Côte d’Ivoire'),
     "ai": CountryPower(voltage=(120, 208, 127, 220, 240, 415), freq=60, country='Anguilla'),
-    "gu": CountryPower(voltage=(190,), freq=60, country='Guam'),
-    "lr": CountryPower(voltage=(208,), freq=60, country='Liberia'),
+    "gu": CountryPower(voltage=TUP_190, freq=60, country='Guam'),
+    "lr": CountryPower(voltage=TUP_208, freq=60, country='Liberia'),
     "br": CountryPower(voltage=(220, 380), freq=60, country='Brazil'),
-    "cv": CountryPower(voltage=(400,), freq=50, country='Cape Verde'),
-    "cl": CountryPower(voltage=(380,), freq=50, country='Chile'),
-    "in": CountryPower(voltage=(400,), freq=50, country='India'),
+    "cv": CountryPower(voltage=TUP_400, freq=50, country='Cape Verde'),
+    "cl": CountryPower(voltage=TUP_380, freq=50, country='Chile'),
+    "in": CountryPower(voltage=TUP_400, freq=50, country='India'),
     "tt": CountryPower(voltage=(115, 230, 230, 400), freq=60, country='Trinidad & Tobago'),
-    "de": CountryPower(voltage=(400,), freq=50, country='Germany'),
-    "pa": CountryPower(voltage=(240,), freq=60, country='Panama'),
-    "qa": CountryPower(voltage=(415,), freq=50, country='Qatar'),
-    "ph": CountryPower(voltage=(380,), freq=60, country='Philippines'),
-    "jo": CountryPower(voltage=(400,), freq=50, country='Jordan'),
-    "mm": CountryPower(voltage=(400,), freq=50, country='Myanmar'),
-    "gd": CountryPower(voltage=(400,), freq=50, country='Grenada'),
-    "st": CountryPower(voltage=(400,), freq=50, country='São Tomé and Príncipe'),
-    "sz": CountryPower(voltage=(400,), freq=50, country='Swaziland'),
-    "ro": CountryPower(voltage=(400,), freq=50, country='Romania'),
+    "de": CountryPower(voltage=TUP_400, freq=50, country='Germany'),
+    "pa": CountryPower(voltage=TUP_240, freq=60, country='Panama'),
+    "qa": CountryPower(voltage=TUP_415, freq=50, country='Qatar'),
+    "ph": CountryPower(voltage=TUP_380, freq=60, country='Philippines'),
+    "jo": CountryPower(voltage=TUP_400, freq=50, country='Jordan'),
+    "mm": CountryPower(voltage=TUP_400, freq=50, country='Myanmar'),
+    "gd": CountryPower(voltage=TUP_400, freq=50, country='Grenada'),
+    "st": CountryPower(voltage=TUP_400, freq=50, country='São Tomé and Príncipe'),
+    "sz": CountryPower(voltage=TUP_400, freq=50, country='Swaziland'),
+    "ro": CountryPower(voltage=TUP_400, freq=50, country='Romania'),
     "xk": CountryPower(voltage=(230, 400), freq=50, country='Kosovo'),
-    "cy": CountryPower(voltage=(400,), freq=50, country='Cyprus'),
-    "dz": CountryPower(voltage=(400,), freq=50, country='Algeria'),
-    "zm": CountryPower(voltage=(400,), freq=50, country='Zambia'),
-    "by": CountryPower(voltage=(380,), freq=50, country='Belarus'),
-    "hr": CountryPower(voltage=(400,), freq=50, country='Croatia'),
-    "lu": CountryPower(voltage=(400,), freq=50, country='Luxembourg'),
-    "fi": CountryPower(voltage=(400,), freq=50, country='Finland'),
-    "zw": CountryPower(voltage=(415,), freq=50, country='Zimbabwe'),
-    "km": CountryPower(voltage=(380,), freq=50, country='Comoros'),
-    "tl": CountryPower(voltage=(380,), freq=50, country='East Timor'),
-    "tz": CountryPower(voltage=(415,), freq=50, country='Tanzania'),
-    "ht": CountryPower(voltage=(190,), freq=60, country='Haiti'),
-    "vc": CountryPower(voltage=(400,), freq=50, country='Saint Vincent and the Grenadines'),
-    "es": CountryPower(voltage=(400,), freq=50, country='Spain'),
-    "my": CountryPower(voltage=(415,), freq=50, country='Malaysia'),
-    "lc": CountryPower(voltage=(400,), freq=50, country='Saint Lucia'),
-    "tm": CountryPower(voltage=(380,), freq=50, country='Turkmenistan'),
+    "cy": CountryPower(voltage=TUP_400, freq=50, country='Cyprus'),
+    "dz": CountryPower(voltage=TUP_400, freq=50, country='Algeria'),
+    "zm": CountryPower(voltage=TUP_400, freq=50, country='Zambia'),
+    "by": CountryPower(voltage=TUP_380, freq=50, country='Belarus'),
+    "hr": CountryPower(voltage=TUP_400, freq=50, country='Croatia'),
+    "lu": CountryPower(voltage=TUP_400, freq=50, country='Luxembourg'),
+    "fi": CountryPower(voltage=TUP_400, freq=50, country='Finland'),
+    "zw": CountryPower(voltage=TUP_415, freq=50, country='Zimbabwe'),
+    "km": CountryPower(voltage=TUP_380, freq=50, country='Comoros'),
+    "tl": CountryPower(voltage=TUP_380, freq=50, country='East Timor'),
+    "tz": CountryPower(voltage=TUP_415, freq=50, country='Tanzania'),
+    "ht": CountryPower(voltage=TUP_190, freq=60, country='Haiti'),
+    "vc": CountryPower(voltage=TUP_400, freq=50, country='Saint Vincent and the Grenadines'),
+    "es": CountryPower(voltage=TUP_400, freq=50, country='Spain'),
+    "my": CountryPower(voltage=TUP_415, freq=50, country='Malaysia'),
+    "lc": CountryPower(voltage=TUP_400, freq=50, country='Saint Lucia'),
+    "tm": CountryPower(voltage=TUP_380, freq=50, country='Turkmenistan'),
     "pe": CountryPower(voltage=(220,), freq=60, country='Peru'),
-    "ua": CountryPower(voltage=(400,), freq=50, country='Ukraine'),
-    "eg": CountryPower(voltage=(380,), freq=50, country='Egypt'),
-    "to": CountryPower(voltage=(415,), freq=50, country='Tonga'),
-    "fr": CountryPower(voltage=(400,), freq=50, country='France'),
-    "ng": CountryPower(voltage=(415,), freq=50, country='Nigeria'),
-    "mw": CountryPower(voltage=(400,), freq=50, country='Malawi'),
-    "ms": CountryPower(voltage=(400,), freq=60, country='Montserrat'),
-    "ae": CountryPower(voltage=(400,), freq=50, country='United Arab Emirates'),
-    "nl": CountryPower(voltage=(400,), freq=50, country='Netherlands'),
-    "id": CountryPower(voltage=(400,), freq=50, country='Indonesia'),
-    "ru": CountryPower(voltage=(380,), freq=50, country='Russia'),
-    "ar": CountryPower(voltage=(380,), freq=50, country='Argentina'),
-    "bn": CountryPower(voltage=(415,), freq=50, country='Brunei'),
-    "pw": CountryPower(voltage=(208,), freq=60, country='Palau'),
-    "kg": CountryPower(voltage=(380,), freq=50, country='Kyrgyzstan'),
-    "bh": CountryPower(voltage=(400,), freq=50, country='Bahrain'),
-    "ml": CountryPower(voltage=(380,), freq=50, country='Mali'),
-    "it": CountryPower(voltage=(400,), freq=50, country='Italy'),
-    "cm": CountryPower(voltage=(380,), freq=50, country='Cameroon'),
-    "ag": CountryPower(voltage=(400,), freq=60, country='Antigua and Barbuda'),
+    "ua": CountryPower(voltage=TUP_400, freq=50, country='Ukraine'),
+    "eg": CountryPower(voltage=TUP_380, freq=50, country='Egypt'),
+    "to": CountryPower(voltage=TUP_415, freq=50, country='Tonga'),
+    "fr": CountryPower(voltage=TUP_400, freq=50, country='France'),
+    "ng": CountryPower(voltage=TUP_415, freq=50, country='Nigeria'),
+    "mw": CountryPower(voltage=TUP_400, freq=50, country='Malawi'),
+    "ms": CountryPower(voltage=TUP_400, freq=60, country='Montserrat'),
+    "ae": CountryPower(voltage=TUP_400, freq=50, country='United Arab Emirates'),
+    "nl": CountryPower(voltage=TUP_400, freq=50, country='Netherlands'),
+    "id": CountryPower(voltage=TUP_400, freq=50, country='Indonesia'),
+    "ru": CountryPower(voltage=TUP_380, freq=50, country='Russia'),
+    "ar": CountryPower(voltage=TUP_380, freq=50, country='Argentina'),
+    "bn": CountryPower(voltage=TUP_415, freq=50, country='Brunei'),
+    "pw": CountryPower(voltage=TUP_208, freq=60, country='Palau'),
+    "kg": CountryPower(voltage=TUP_380, freq=50, country='Kyrgyzstan'),
+    "bh": CountryPower(voltage=TUP_400, freq=50, country='Bahrain'),
+    "ml": CountryPower(voltage=TUP_380, freq=50, country='Mali'),
+    "it": CountryPower(voltage=TUP_400, freq=50, country='Italy'),
+    "cm": CountryPower(voltage=TUP_380, freq=50, country='Cameroon'),
+    "ag": CountryPower(voltage=TUP_400, freq=60, country='Antigua and Barbuda'),
     "mr": CountryPower(voltage=(220,), freq=50, country='Mauritania'),
-    "om": CountryPower(voltage=(415,), freq=50, country='Oman'),
-    "lk": CountryPower(voltage=(400,), freq=50, country='Sri Lanka'),
-    "er": CountryPower(voltage=(400,), freq=50, country='Eritrea'),
-    "mk": CountryPower(voltage=(400,), freq=50, country='Macedonia, Republic of'),
-    "ni": CountryPower(voltage=(208,), freq=60, country='Nicaragua'),
-    "ch": CountryPower(voltage=(400,), freq=50, country='Switzerland'),
-    "ca": CountryPower(voltage=(120, 208, 240, 480, 347, 600), freq=60, country='Canada'),
-    "cr": CountryPower(voltage=(240,), freq=60, country='Costa Rica')
+    "om": CountryPower(voltage=TUP_415, freq=50, country='Oman'),
+    "lk": CountryPower(voltage=TUP_400, freq=50, country='Sri Lanka'),
+    "er": CountryPower(voltage=TUP_400, freq=50, country='Eritrea'),
+    "mk": CountryPower(voltage=TUP_400, freq=50, country='Macedonia, Republic of'),
+    "ni": CountryPower(voltage=TUP_208, freq=60, country='Nicaragua'),
+    "ch": CountryPower(voltage=TUP_400, freq=50, country='Switzerland'),
+    "ca": CountryPower(voltage=(120, 208, 240, CONST_480, 347, 600), freq=60, country='Canada'),
+    "cr": CountryPower(voltage=TUP_240, freq=60, country='Costa Rica')
 }
+'''Dictionary of country-code to CountryPower instances for industrial use.'''
 
-plug_types = ['A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'J', 'K', 'L', 'M', 'N']
+electrical_plug_types = ['A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'J', 'K', 'L', 'M', 'N']
+'''List of all electrical plug types in use around the world.'''
 voltages_1_phase_residential = [100, 110, 115, 120, 127, 220, 230, 240]
+'''List of all AC 1-phase voltages used in residential settings around the world.'''
 voltages_3_phase = [120, 190, 200, 208, 220, 230, 240, 277, 380, 400, 415, 440, 480]
-frequencies = [50, 60]
+'''List of all AC 3-phase voltages used in industrial settings around the world.'''
+residential_power_frequencies = [50, 60]
+'''List of all AC 1-phase frequencies used in residential settings around the world.'''
 
 
 # https://www.grainger.com/content/supplylink-v-belt-maintenance-key-to-electric-motor-efficiency
@@ -1090,7 +1158,7 @@ SPHERICAL_ROLLER_THRUST: 0.0018}
 
 # In m, diameter of fans
 fan_diameters = [0.125, 0.132, 0.14, 0.15, 0.16, 0.17, 0.18, 0.19, 0.2, 0.212,
-                 0.224, 0.236, 0.25, 0.265, 0.28, 0.3, 0.315, 0.335, 0.355, 
+                 0.224, 0.236, 0.25, 0.265, 0.28, 0.3, 0.315, 0.335, 0.355,
                  0.375, 0.4, 0.425, 0.45, 0.475, 0.5, 0.53, 0.56, 0.6, 0.63,
                  0.67, 0.71, 0.75, 0.8, 0.85, 0.9, 0.95, 1.0]
 
@@ -1117,7 +1185,7 @@ fan_bare_shaft_efficiencies = {'FEG90': FEG90,
                                'FEG56': FEG56,
                                'FEG53': FEG53,
                                'FEG50': FEG50}
-        
+
 '''for key, values in fan_bare_shaft_efficiencies.items():
     plt.plot(fan_diameters, values, label=key)
 
