@@ -17,7 +17,7 @@ Some tests were changed and added as well.
 
 
 The copyright notice (BSD-3 clause) is as follows:
-    
+
 BSD 3-Clause License
 
 Copyright (c) 2013-2018, Sandia National Laboratories and pvlib python Development Team
@@ -48,9 +48,9 @@ ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 """
-    
 
-    
+
+
 import os
 import datetime as dt
 
@@ -76,13 +76,15 @@ try:
                             numba_version.split('.')[1])
 except ImportError:
     numba_version_int = 0
+except:
+    numba_version_int = -1
 
 from fluids.optional import spa
 
 times = (pd.date_range('2003-10-17 12:30:30', periods=1, freq='D')
            .tz_localize('MST'))
-unixtimes = np.array(times.tz_convert('UTC').astype(np.int64)*1.0/10**9)
-
+unixtimes = np.array(times.tz_convert('UTC').view(np.int64)*1.0/10**9)
+unixtimes = float(np.array(times.tz_convert('UTC').view(np.int64)*1.0/10**9)[0])
 lat = 39.742476
 lon = -105.1786
 elev = 1830.14
@@ -129,7 +131,7 @@ theta = 50.11162
 theta0 = 90 - e0
 Gamma = 14.340241
 Phi = 194.340241
-year = 1985 
+year = 1985
 month = 2
 year_array = np.array([-499, 500, 1000, 1500, 1800, 1900, 1950, 1970, 1985, 1990, 2000, 2005])
 month_array = np.array([1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12])
@@ -141,7 +143,7 @@ dt_actual_array = np.array([1.7184831e+04, 5.7088051e+03, 1.5730419e+03,
 mix_year_array = np.full((10), year)
 mix_month_array = np.full((10), month)
 mix_year_actual = np.full((10), dt_actual)
-mix_month_actual = mix_year_actual 
+mix_month_actual = mix_year_actual
 
 class SpaBase(object):
     """Test functions common to numpy and numba spa"""
@@ -290,14 +292,10 @@ class SpaBase(object):
         assert_almost_equal(Phi, self.spa.topocentric_azimuth_angle(Gamma), 5)
 
     def test_solar_position(self):
-        assert_almost_equal(
-            np.array([[theta, theta0, e, e0, Phi]]).T, self.spa.solar_position(
-                unixtimes, lat, lon, elev, pressure, temp, delta_t,
-                atmos_refract)[:-1], 5)
-        assert_almost_equal(
-            np.array([[v, alpha, delta]]).T, self.spa.solar_position(
-                unixtimes, lat, lon, elev, pressure, temp, delta_t,
-                atmos_refract, sst=True)[:3], 5)
+        assert_almost_equal(np.array([theta, theta0, e, e0, Phi]),
+                            self.spa.solar_position(unixtimes, lat, lon, elev, pressure, temp, delta_t, atmos_refract)[:-1], 5)
+        assert_almost_equal(np.array([v, alpha, delta]),
+                            self.spa.solar_position(unixtimes, lat, lon, elev, pressure, temp, delta_t, atmos_refract, sst=True)[:3], 5)
 
     def test_equation_of_time(self):
         eot = 14.64
@@ -309,33 +307,35 @@ class SpaBase(object):
         # tests at greenwich
         times = pd.DatetimeIndex([dt.datetime(1996, 7, 5, 0),
                                   dt.datetime(2004, 12, 4, 0)]
-                                 ).tz_localize('UTC').astype(np.int64)*1.0/10**9
+                                 ).tz_localize('UTC').view(np.int64)*1.0/10**9
         sunrise = pd.DatetimeIndex([dt.datetime(1996, 7, 5, 7, 8, 15),
                                     dt.datetime(2004, 12, 4, 4, 38, 57)]
-                                   ).tz_localize('UTC').astype(np.int64)*1.0/10**9
+                                   ).tz_localize('UTC').view(np.int64)*1.0/10**9
         sunset = pd.DatetimeIndex([dt.datetime(1996, 7, 5, 17, 1, 4),
                                    dt.datetime(2004, 12, 4, 19, 2, 2)]
-                                  ).tz_localize('UTC').astype(np.int64)*1.0/10**9
+                                  ).tz_localize('UTC').view(np.int64)*1.0/10**9
         times = np.array(times)
         sunrise = np.array(sunrise)
         sunset = np.array(sunset)
-        result = self.spa.transit_sunrise_sunset(times, -35.0, 0.0, 64.0, 1)
-        assert_almost_equal(sunrise/1e3, result[1]/1e3, 3)
-        assert_almost_equal(sunset/1e3, result[2]/1e3, 3)
+        result = [self.spa.transit_sunrise_sunset(t, -35.0, 0.0, 64.0) for t in times]
+        for i in range(2):
+            assert_almost_equal(sunrise[i]/1e3, result[i][1]/1e3, 3)
+            assert_almost_equal(sunset[i]/1e3, result[i][2]/1e3, 3)
 
 
         times = pd.DatetimeIndex([dt.datetime(1994, 1, 2),]
-                                 ).tz_localize('UTC').astype(np.int64)*1.0/10**9
+                                 ).tz_localize('UTC').view(np.int64)*1.0/10**9
         sunset = pd.DatetimeIndex([dt.datetime(1994, 1, 2, 16, 59, 55),]
-                                  ).tz_localize('UTC').astype(np.int64)*1.0/10**9
+                                  ).tz_localize('UTC').view(np.int64)*1.0/10**9
         sunrise = pd.DatetimeIndex([dt.datetime(1994, 1, 2, 7, 8, 12),]
-                                   ).tz_localize('UTC').astype(np.int64)*1.0/10**9
+                                   ).tz_localize('UTC').view(np.int64)*1.0/10**9
         times = np.array(times)
         sunrise = np.array(sunrise)
         sunset = np.array(sunset)
-        result = self.spa.transit_sunrise_sunset(times, 35.0, 0.0, 64.0, 1)
-        assert_almost_equal(sunrise/1e3, result[1]/1e3, 3)
-        assert_almost_equal(sunset/1e3, result[2]/1e3, 3)
+        result = [self.spa.transit_sunrise_sunset(t, 35.0, 0.0, 64.0) for t in times]
+        for i in range(1):
+            assert_almost_equal(sunrise[i]/1e3, result[i][1]/1e3, 3)
+            assert_almost_equal(sunset[i]/1e3, result[i][2]/1e3, 3)
 
         # tests from USNO
         # Golden
@@ -343,65 +343,67 @@ class SpaBase(object):
                                   dt.datetime(2015, 4, 2),
                                   dt.datetime(2015, 8, 2),
                                   dt.datetime(2015, 12, 2),],
-                                 ).tz_localize('UTC').astype(np.int64)*1.0/10**9
+                                 ).tz_localize('UTC').view(np.int64)*1.0/10**9
         sunrise = pd.DatetimeIndex([dt.datetime(2015, 1, 2, 7, 19),
                                     dt.datetime(2015, 4, 2, 5, 43),
                                     dt.datetime(2015, 8, 2, 5, 1),
                                     dt.datetime(2015, 12, 2, 7, 1),],
-                                   ).tz_localize('MST').astype(np.int64)*1.0/10**9
+                                   ).tz_localize('MST').view(np.int64)*1.0/10**9
         sunset = pd.DatetimeIndex([dt.datetime(2015, 1, 2, 16, 49),
                                    dt.datetime(2015, 4, 2, 18, 24),
                                    dt.datetime(2015, 8, 2, 19, 10),
                                    dt.datetime(2015, 12, 2, 16, 38),],
-                                  ).tz_localize('MST').astype(np.int64)*1.0/10**9
+                                  ).tz_localize('MST').view(np.int64)*1.0/10**9
         times = np.array(times)
         sunrise = np.array(sunrise)
         sunset = np.array(sunset)
-        result = self.spa.transit_sunrise_sunset(times, 39.0, -105.0, 64.0, 1)
-        assert_almost_equal(sunrise/1e3, result[1]/1e3, 1)
-        assert_almost_equal(sunset/1e3, result[2]/1e3, 1)
+        result = [self.spa.transit_sunrise_sunset(t, 39.0, -105.0, 64.0) for t in times]
+        for i in range(4):
+            assert_almost_equal(sunrise[i]/1e3, result[i][1]/1e3, 1)
+            assert_almost_equal(sunset[i]/1e3, result[i][2]/1e3, 1)
 
         # Beijing
         times = pd.DatetimeIndex([dt.datetime(2015, 1, 2),
                                   dt.datetime(2015, 4, 2),
                                   dt.datetime(2015, 8, 2),
                                   dt.datetime(2015, 12, 2),],
-                                 ).tz_localize('UTC').astype(np.int64)*1.0/10**9
+                                 ).tz_localize('UTC').view(np.int64)*1.0/10**9
         sunrise = pd.DatetimeIndex([dt.datetime(2015, 1, 2, 7, 36),
                                     dt.datetime(2015, 4, 2, 5, 58),
                                     dt.datetime(2015, 8, 2, 5, 13),
                                     dt.datetime(2015, 12, 2, 7, 17),],
                                    ).tz_localize('Asia/Shanghai'
-                                   ).astype(np.int64)*1.0/10**9
+                                   ).view(np.int64)*1.0/10**9
         sunset = pd.DatetimeIndex([dt.datetime(2015, 1, 2, 17, 0),
                                    dt.datetime(2015, 4, 2, 18, 39),
                                    dt.datetime(2015, 8, 2, 19, 28),
                                    dt.datetime(2015, 12, 2, 16, 50),],
                                   ).tz_localize('Asia/Shanghai'
-                                  ).astype(np.int64)*1.0/10**9
+                                  ).view(np.int64)*1.0/10**9
         times = np.array(times)
         sunrise = np.array(sunrise)
         sunset = np.array(sunset)
-        result = self.spa.transit_sunrise_sunset(times, 39.917, 116.383, 64.0,1)
-        assert_almost_equal(sunrise/1e3, result[1]/1e3, 1)
-        assert_almost_equal(sunset/1e3, result[2]/1e3, 1)
+        result = [self.spa.transit_sunrise_sunset(t, 39.917, 116.383, 64.0) for t in times]
+        for i in range(4):
+            assert_almost_equal(sunrise[i]/1e3, result[i][1]/1e3, 1)
+            assert_almost_equal(sunset[i]/1e3, result[i][2]/1e3, 1)
 
     def test_earthsun_distance(self):
         times = (pd.date_range('2003-10-17 12:30:30', periods=1, freq='D')
            .tz_localize('MST'))
-        unixtimes = times.tz_convert('UTC').astype(np.int64)*1.0/10**9
-        unixtimes = np.array(unixtimes)
-        result = self.spa.earthsun_distance(unixtimes, 64.0, 1)
+        unixtimes = times.tz_convert('UTC').view(np.int64)*1.0/10**9
+        unixtimes = float(np.array(unixtimes)[0])
+        result = self.spa.earthsun_distance(unixtimes, 64.0)
         assert_almost_equal(R, result, 6)
 
     def test_calculate_deltat(self):
-        result_mix_year = self.spa.calculate_deltat(mix_year_array, month)
+        result_mix_year = [self.spa.calculate_deltat(t, month) for t in mix_year_array]
         assert_almost_equal(mix_year_actual, result_mix_year)
 
         result_mix_month = self.spa.calculate_deltat(year, mix_month_array)
         assert_almost_equal(mix_month_actual, result_mix_month)
 
-        result_array = self.spa.calculate_deltat(year_array, month_array)
+        result_array = [self.spa.calculate_deltat(t, m) for t, m in zip(year_array, month_array)]
         assert_almost_equal(dt_actual_array, result_array, 3)
 
         result_scalar = self.spa.calculate_deltat(year,month)
@@ -420,7 +422,7 @@ class NumpySpaTest(unittest.TestCase, SpaBase):
         pass
 
     def test_julian_day(self):
-        assert_almost_equal(JD, self.spa.julian_day(unixtimes)[0], 6)
+        assert_almost_equal(JD, self.spa.julian_day(unixtimes), 6)
 
 
 @pytest.mark.skipif(numba_version_int < 17,
@@ -439,34 +441,17 @@ class NumbaSpaTest(unittest.TestCase, SpaBase):
         pass
 
     def test_julian_day(self):
-        assert_almost_equal(JD, self.spa.julian_day(unixtimes[0]), 6)
+        assert_almost_equal(JD, self.spa.julian_day(unixtimes), 6)
 
     def test_solar_position_singlethreaded(self):
         assert_almost_equal(
-            np.array([[theta, theta0, e, e0, Phi]]).T, self.spa.solar_position(
+            np.array([theta, theta0, e, e0, Phi]), self.spa.solar_position(
                 unixtimes, lat, lon, elev, pressure, temp, delta_t,
-                atmos_refract, numthreads=1)[:-1], 5)
+                atmos_refract)[:-1], 5)
         assert_almost_equal(
-            np.array([[v, alpha, delta]]).T, self.spa.solar_position(
+            np.array([v, alpha, delta]), self.spa.solar_position(
                 unixtimes, lat, lon, elev, pressure, temp, delta_t,
-                atmos_refract, numthreads=1, sst=True)[:3], 5)
-
-    def test_solar_position_multithreaded(self):
-        result = np.array([theta, theta0, e, e0, Phi])
-        nresult = np.array([result, result, result]).T
-        times = np.array([unixtimes[0], unixtimes[0], unixtimes[0]])
-        assert_almost_equal(
-            nresult
-            , self.spa.solar_position(
-                times, lat, lon, elev, pressure, temp, delta_t,
-                atmos_refract, numthreads=8)[:-1], 5)
-        result = np.array([v, alpha, delta])
-        nresult = np.array([result, result, result]).T
-        assert_almost_equal(
-            nresult
-            , self.spa.solar_position(
-                times, lat, lon, elev, pressure, temp, delta_t,
-                atmos_refract, numthreads=8, sst=True)[:3], 5)
+                atmos_refract, sst=True)[:3], 5)
 
 
 try:
@@ -475,17 +460,17 @@ except:
     astropy = None
 @pytest.mark.skipif(astropy is None, reason='Astropy is not installed')
 def test_deltat_astropy():
-    # Can't do a full range of tests because astropy doesn't have 
+    # Can't do a full range of tests because astropy doesn't have
     # answers before 1960, after 1999 in this version
     from astropy.time import Time
     from datetime import datetime
     def delta_t_astropy(dt):
         t = Time(dt, scale='utc')
         return -(dt - t.tt.value).total_seconds()
-    
+
 #    years = range(1, 3000, 100) + [3000]
     years = range(1960, 1999, 1)
-    
+
     months = range(1, 13)
     for year in years:
         for month in months:
@@ -493,3 +478,13 @@ def test_deltat_astropy():
             dt = datetime(year, month, 1)
             delta_t_external = delta_t_astropy(dt)
             assert_allclose(delta_t_pvlib, delta_t_external, atol=.5, rtol=.01)
+
+#suite = unittest.TestSuite()
+#suite.addTest(NumpySpaTest("testItIsHot"))
+#runner = unittest.TextTestRunner()
+#runner.run(suite)
+#
+#NumpySpaTest.test_calculate_deltat()
+
+if __name__ == '__main__':
+    unittest.main()
